# We have to override the new %%install behavior because, well... the kernel is special.
%global __spec_install_pre %{___build_pre}

Summary: The Linux Realtime kernel

# Force the dist to be .el7
%global dist .el7

%global __spec_install_pre %{___build_pre}

# realtimeN
%global rtbuild 429

# RHEL7 build number
%global rhel_build 514.6.1

# The preempt RT patch level
%global rttag rt56

# For a kernel released for public testing, released_kernel should be 1.
# For internal testing builds during development, it should be 0.
%global released_kernel 0

# conditional with/without variables
# Note that the logic here is inverted; a  bcond_without implies
# that the variable is on by default (since you use --without to turn it off)
# Likewise a bcond_with implies the variable is off by default (turned on by --with)
%bcond_without rt
%bcond_without doc
%bcond_without debug
%bcond_with    headers
%bcond_with    vanilla
%bcond_without trace
%bcond_with    perf
%bcond_with    firmware
%bcond_without debuginfo
%bcond_without dracut

# What parts do we want to build?  We must build at least one kernel.
# These are the kernels that are built IF the architecture allows it.
# Note that these are regular macros, not the bcond macros defined above,
# so they can be reassigned inside the spec file.

%global buildrt        %{with rt}
%global builddoc       %{with doc}
%global builddebug     %{with debug}
%global buildheaders   %{with headers}
%global buildvanilla   %{with vanilla}
%global buildtrace     %{with trace}
%global buildperf      %{with perf}
%global buildfirmware  %{with firmware}
%global builddebuginfo %{with debuginfo}


# Verbose output?
# %%global verbose V=1

# use dracut or mkinitrd?
%global use_dracut    %{with dracut}

# Versions of various parts

# Polite request for people who spin their own kernel rpms:
# please modify the "buildid" define in a way that identifies
# that the kernel isn't the stock distribution kernel, for example,
# by setting the define to ".local" or ".bz123456"
#
# %%define buildid .local

%global rhel 1
%if %{rhel}
%global distro_build  0
%global signmodules 1
%else
# fedora_build defines which build revision of this kernel version we're
# building. Rather than incrementing forever, as with the prior versioning
# setup, we set fedora_cvs_origin to the current cvs revision s/1.// of the
# kernel spec when the kernel is rebased, so fedora_build automatically
# works out to the offset from the rebase, so it doesn't get too ginormous.
#
# If you're building on a branch, the RCS revision will be something like
# 1.1205.1.1.  In this case we drop the initial 1, subtract fedora_cvs_origin
# from the second number, and then append the rest of the RCS string as is.
# Don't stare at the awk too long, you'll go blind.
%global fedora_cvs_origin   1462
%global fedora_cvs_revision() %2
%global distro_build %(echo %{fedora_cvs_origin}.%{fedora_cvs_revision $Revision: 1.694 $} | awk -F . '{ OFS = "."; ORS = ""; print $3 - $1 ; i = 4 ; OFS = ""; while (i <= NF) { print ".", $i ; i++} }')
%global distro_build %{fedora_build}
%global signmodules 0
%endif

# if patch fuzzy patch applying will be forbidden
%global with_fuzzy_patches 0

%global rpmversion 3.10.0


# What parts do we want to build?  We must build at least one kernel.
# These are the kernels that are built IF the architecture allows it.
# All should default to 1 (enabled) and be flipped to 0 (disabled)
# by later arch-specific checks.

# The following build options are enabled by default.
# Use either --without <opt> in your rpmbuild command or force values
# to 0 in here to disable them.
#
# perf noarch subpkg
%global with_vdso_install 1

# Build the kernel-doc package, but don't fail the build if it botches.
# Here "true" means "continue" and "false" means "fail the build".
%global doc_build_fail true

# Additional options for user-friendly one-off kernel building:
# Only build the base kernel (--with baseonly):
%global with_baseonly  0
# Only build the debug kernel (--with dbgonly):
%global with_dbgonly   0

# should we do C=1 builds with sparse
%global with_sparse	%{?_with_sparse:      1} %{?!_with_sparse:      0}

%global pkg_release_simple %{rhel_build}%{?buildid}.%{rttag}.%{rtbuild}

%global pkg_release %{pkg_release_simple}%{?dist}

%global KVERREL %{rpmversion}-%{pkg_release}.%{_target_cpu}

# The kernel tarball/base version
%global kversion %{rpmversion}

%define with_gcov %{?_with_gcov: 1} %{?!_with_gcov: 0}

%global make_target bzImage

%global KVRA %{version}-%{release}.%{_target_cpu}
%global hdrarch %_target_cpu
%global asmarch %_target_cpu
%global cross_target %{_target_cpu}

%if !%{builddebuginfo}
%global _enable_debug_packages 0
%global fancy_debuginfo 0
%else
%global _enable_debug_packages 1
%global fancy_debuginfo 1
%endif
%global debuginfodir /usr/lib/debug

# if requested, only build base kernel
%if %{with_baseonly}
%global builddebug 0
%global buildtrace 0
%global buildvanilla 0
%global buildperf 0
%global buildheaders 0
%global builddebuginfo 0
%endif

# if requested, only build debug kernel
%if %{with_dbgonly}
%if %{debugbuildsenabled}
%global buildrt 0
%endif
%global buildperf 0
%endif

%global all_x86 i386 i686

%if %{with_vdso_install}
# These arches install vdso/ directories.
%global vdso_arches %{all_x86} x86_64
%endif


# don't do debug builds on anything but i686 and x86_64
%ifnarch i686 x86_64
%global builddebug 0
%endif

# only package docs if we're noarch
%ifnarch noarch
%global builddoc 0
%global buildfirmware 0
%endif

# don't build noarch kernels or headers (duh)
%ifarch noarch
%global buildrt 0
%global buildheaders 0
%global buildperf 0
%global buildtrace 0
%global buildvanilla 0
%global all_arch_configs kernel-%{version}-*.config
%endif

# Per-arch tweaks

%global asmarch x86
%global image_install_path boot
%global kernel_image arch/x86/boot/bzImage

%ifarch %{all_x86}
%global hdrarch i386
%global all_arch_configs kernel-%{rpmversion}-i?86-rt*.config
%endif

%ifarch x86_64
%global all_arch_configs kernel-%{rpmversion}-x86_64-rt*.config
%endif

%global oldconfig_target oldconfig

# Should make listnewconfig fail if there's config options
# # printed out?
%define listnewconfig_fail 1

# To temporarily exclude an architecture from being built, add it to
# %nobuildarches. Do _NOT_ use the ExclusiveArch: line, because if we
# don't build kernel-headers then the new build system will no longer let
# us use the previous build of that package -- it'll just be completely AWOL.
# Which is a BadThing(tm).

# We don't build a kernel on i386; we only do kernel-headers there,
# and we no longer build for 31bit S390. Same for 32bit sparc and arm.
%global nobuildarches i386 i586 i686 s390 sparc sparc64 ppc ppc64le ia64 aarch64 noarch

%ifarch %nobuildarches
%global buildrt 0
%global builddebug 0
%global buildvanilla 0
%global buildtrace 0
%global builddebuginfo 0
%global buildperf 0
%global _enable_debug_packages 0
%endif

#
# Three sets of minimum package version requirements in the form of Conflicts:
# to versions below the minimum
#

#
# First the general kernel 3.0 required versions as per
# Documentation/Changes
#
%global kernel_dot_org_conflicts  ppp < 2.4.3-3, isdn4k-utils < 3.2-32, nfs-utils < 1.0.7-12, e2fsprogs < 1.37-4, util-linux < 2.12, jfsutils < 1.1.7-2, reiserfs-utils < 3.6.19-2, xfsprogs < 2.6.13-4, procps < 3.2.5-6.3, oprofile < 0.9.1-2, device-mapper-libs < 1.02.63-2, mdadm < 3.2.1-5

#
# Then a series of requirements that are distribution specific, either
# because we add patches for something, or the older versions have
# problems with the newer kernel or lack certain things that make
# integration in the distro harder than needed.
#
%global package_conflicts initscripts < 7.23, udev < 145-11, iptables < 1.3.2-1, ipw2200-firmware < 2.4, iwl4965-firmware < 228.57.2, selinux-policy-targeted < 1.25.3-14, squashfs-tools < 4.0, wireless-tools < 29-3

# We moved the drm include files into kernel-headers, make sure there's
# a recent enough libdrm-devel on the system that doesn't have those.
%global kernel_headers_conflicts libdrm-devel < 2.4.0-0.15

#
# Packages that need to be installed before the kernel is, because the %%post
# scripts use them.
#
%global kernel_prereq  fileutils, module-init-tools >= 3.16-2, initscripts >= 8.11.1-1, grubby >= 8.28-2, rt-setup >= 1.55

%if %{use_dracut}
%global initrd_prereq  dracut-kernel >= 001-7
%else
%global initrd_prereq  mkinitrd >= 6.0.61-1
%endif

#
# This macro does requires, provides, conflicts, obsoletes for a kernel package.
#	%%kernel_reqprovconf <subpackage>
# It uses any kernel_<subpackage>_conflicts and kernel_<subpackage>_obsoletes
# macros defined above.
#
%define kernel_reqprovconf \
Provides: installonlypkg(kernel) = %{rpmversion}-%{pkg_release}\
Provides: kernel = %{rpmversion}-%{pkg_release}\
Provides: kernel-%{_target_cpu} = %{rpmversion}-%{pkg_release}%{?1:.%{1}}\
Provides: kernel-drm = 4.3.0\
Provides: kernel-drm-nouveau = 16\
Provides: kernel-modeset = 1\
Provides: kernel-uname-r = %{KVERREL}%{?1:.%{1}}\
Requires(pre): %{kernel_prereq}\
Requires(pre): %{initrd_prereq}\
Requires(pre): linux-firmware >= 20150904-43\
Requires(post): %{_sbindir}/new-kernel-pkg\
Requires(preun): %{_sbindir}/new-kernel-pkg\
Conflicts: %{kernel_dot_org_conflicts}\
Conflicts: %{package_conflicts}\
%{expand:%%{?kernel%{?1:_%{1}}_conflicts:Conflicts: %%{kernel%{?1:_%{1}}_conflicts}}}\
%{expand:%%{?kernel%{?1:_%{1}}_obsoletes:Obsoletes: %%{kernel%{?1:_%{1}}_obsoletes}}}\
%{expand:%%{?kernel%{?1:_%{1}}_provides:Provides: %%{kernel%{?1:_%{1}}_provides}}}\
# We can't let RPM do the dependencies automatic because it'll then pick up\
# a correct but undesirable perl dependency from the module headers which\
# isn't required for the kernel proper to function\
AutoReq: no\
AutoProv: yes\
%{nil}

Name: kernel-rt
Group: System Environment/Kernel
License: GPLv2
URL: http://www.kernel.org/
Version: %{rpmversion}
Release: %{pkg_release}
# DO NOT CHANGE THE 'ExclusiveArch' LINE TO TEMPORARILY EXCLUDE AN ARCHITECTURE BUILD.
# SET %%nobuildarches (ABOVE) INSTEAD
ExclusiveArch: noarch x86_64
ExclusiveOS: Linux
Provides: installonlypkg(kernel-rt) = %{rpmversion}
Provides: kernel-rt-drm = 4.3.0
Provides: kernel-rt-%{_target_cpu} = %{rpmversion}-%{pkg_release}

%kernel_reqprovconf
%ifarch x86_64
Obsoletes: kernel-smp
%endif

#
# List the packages used during the kernel build
#
BuildRequires: module-init-tools, patch >= 2.5.4, bash >= 2.03, sh-utils, tar
BuildRequires: bzip2, findutils, gzip, m4, perl, make >= 3.78, diffutils, gawk
BuildRequires: gcc >= 3.4.2, binutils >= 2.12, redhat-rpm-config
BuildRequires: hostname, net-tools, patchutils, rpm-build >= 4.8.0-7, bc
BuildRequires: openssl
BuildRequires: hmaccalc
BuildRequires: elfutils-libelf-devel
%ifarch x86_64
BuildRequires: pesign >= 0.109-4
%endif
Buildrequires: xz
%if %{builddoc}
BuildRequires: xmlto
BuildRequires: asciidoc
%endif
%if %{with_sparse}
BuildRequires: sparse >= 0.4.1
%endif
%if %{buildrt}
%if %{buildperf}
BuildRequires: elfutils-libelf-devel zlib-devel binutils-devel newt-devel python-devel perl(ExtUtils::Embed)
BuildRequires: elfutils-devel asciidoc xmlto
BuildRequires: audit-libs-devel
%endif
%endif
%if %{signmodules}
BuildRequires: gnupg
%endif
BuildRequires: python

BuildConflicts: rhbuildsys(DiskFree) < 7Gb

%if %{fancy_debuginfo}
# Fancy new debuginfo generation introduced in Fedora 8.
# Note this must be a define since it needs to be overridden in some macro
# expansions
%define debuginfo_args --strict-build-id
%endif

Source0: %{name}-%{rpmversion}-%{pkg_release_simple}.tar.xz

Source10: sign-modules
%define modsign_cmd %{SOURCE10}
Source11: genkey
Source12: perf
Source13: perf-archive
Source14: find-provides
Source15: merge.pl
Source17: sanity_check.py
Source19: extrakeys.pub

Source31: x509.genkey
Source32: extra_certificates
Source33: centos.cer
Source34: secureboot.cer
Source35: centos-ldup.x509
Source36: centos-kpatch.x509

### Configuration files
Source50: kernel-%{version}-x86_64-rt.config
Source51: kernel-%{version}-x86_64-rt-trace.config
Source52: kernel-%{version}-x86_64-rt-debug.config

### Started using a unified SRPM

# Bugzilla: 1209952
#
# Commit 32b3809 broke the manual kernel build because it depended on
# variables set in the specfile during the RPM build process.
#
# Commit 32b3809 was reverted and the new solution will be applying
# those changes at the %build section of the specfile.
Patch001: avoid-debuginfo-hash-collision-scripts.patch

# Empty final patch file to facilitate testing of kernel patches
Patch999999: linux-kernel-test.patch
Patch1000: debrand-single-cpu.patch
Patch1001: debrand-rh_taint.patch
Patch1002: debrand-rh-i686-cpu.patch


BuildRoot: %{_tmppath}/kernel-%{KVERREL}-root

# Override find_provides to use a script that provides "kernel(symbol) = hash".
# Pass path of the RPM temp dir containing kabideps to find-provides script.
# Note: double '%%' was used to prevent macro expansion in comments
# %%global _use_internal_dependency_generator 0
# %%global __find_provides %%_sourcedir/find-provides %%{_tmppath}
# %%global __find_requires /usr/lib/rpm/redhat/find-requires kernel

%description
The kernel-rt package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system: memory allocation, process allocation, device
input and output, etc.

This kernel has been compiled withe the RT patch applied and is intended
for use in deterministic response-time situations


%package doc
Summary: Various documentation bits found in the kernel source
Group: Documentation
%description doc
This package contains documentation files from the kernel
source. Various bits of information about the Linux kernel and the
device drivers shipped with it are documented in these files.

You will want to install this package if you need a reference to the
options that can be passed to Linux kernel modules at load time.


%package headers
Summary: Header files for the Linux kernel for use by glibc
Group: Development/System
Obsoletes: glibc-kernheaders
Provides: glibc-kernheaders = 3.0-46
%description headers
Kernel-headers includes the C header files that specify the interface
between the Linux kernel and userspace libraries and programs.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
glibc package.

%package firmware
Summary: Firmware files used by the Linux kernel
Group: Development/System
# This is... complicated.
# Look at the WHENCE file.
License: GPL+ and GPLv2+ and MIT and Redistributable, no modification permitted
Provides: kernel-firmware = %{rpmversion}-%{pkg_release}
Provides: kernel-rt-firmware = %{rpmversion}-%{pkg_release}
%description firmware
Kernel-firmware includes firmware files required for some devices to
operate.

%if %{builddebuginfo}
%package debuginfo-common-%{_target_cpu}
Summary: Kernel source files used by %{name}-debuginfo packages
Group: Development/Debug
%description debuginfo-common-%{_target_cpu}
This package is required by %{name}-debuginfo subpackages.
It provides the kernel source files common to all builds.
%endif

%if %{buildrt}
%if %{buildperf}
%package -n perf-rt
Summary: Performance monitoring for the Linux kernel
Group: Development/System
Provides: perl(Perf::Trace::Context), perl(Perf::Trace::Core), perl(Perf::Trace::Util)
License: GPLv2
Obsoletes: perf
%description -n perf-rt
This package provides the supporting documentation for the perf tool
shipped in each kernel image subpackage.
%endif
%endif

#
# this macro creates a kernel-rt-<subpackage>-kvm package
# %%kernel_kvm_package <subpackage>
#
%define kernel_kvm_package() \
%package %{?1:%{1}-}kvm\
Summary: KVM modules for package %{name}%{?1:-%{1}}\
Group: System Environment/Kernel\
Requires: %{name} = %{version}-%{release}\
Provides: installonlypkg(kernel-rt-kvm) = %{version}-%{release}\
Provides: kernel-rt%{?1:-%{1}}-kvm = %{version}-%{release}%{?1:.%{1}}\
Provides: kernel-rt-kvm-%{_target_cpu} = %{version}-%{release}%{?1:.%{1}}\
AutoReq: no\
%description -n %{name}%{?1:-%{1}}-kvm\
This package provides KVM modules for package %{name}%{?1:-%{1}}.\
%{nil}

#
# This macro creates a kernel-rt-<subpackage>-kvm-debuginfo package.
#	%%kernel_kvm_debuginfo_package <subpackage>
#
%define kernel_kvm_debuginfo_package() \
%package %{?1:%{1}-}kvm-debuginfo\
Summary: Debug information for package %{name}%{?1:-%{1}}-kvm\
Group: Development/Debug\
Provides: %{name}%{?1:-%{1}}-kvm-debuginfo = %{version}-%{release}\
AutoReqProv: no\
%description -n %{name}%{?1:-%{1}}-kvm-debuginfo\
This package provides debug information for package %{name}%{?1:-%{1}}.\
This is required to use SystemTap with %{name}%{?1:%{1}}-%{KVERREL}.\
%{expand:%%global debuginfo_args %{?debuginfo_args} -p '/.*/%%{KVERREL}%{?1:\.%{1}}/.*|/.*%%{KVERREL}%{?1:\.%{1}}(\.debug)?' -o debuginfo%{?1}-kvm.list}\
%{nil}

#
# This macro creates a kernel-<subpackage>-debuginfo package.
#	%%kernel_debuginfo_package <subpackage>
#
%define kernel_debuginfo_package() \
%package %{?1:%{1}-}debuginfo\
Summary: Debug information for package %{name}%{?1:-%{1}}\
Group: Development/Debug\
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}\
Provides: %{name}%{?1:-%{1}}-debuginfo-%{_target_cpu} = %{version}-%{release}\
AutoReqProv: no\
%description -n %{name}%{?1:-%{1}}-debuginfo\
This package provides debug information for package %{name}%{?1:-%{1}}.\
This is required to use SystemTap with %{name}%{?1:%{1}}-%{KVERREL}.\
%{expand:%%global debuginfo_args %{?debuginfo_args} -p '/.*/%%{KVERREL}%{?1:\.%{1}}/.*|/.*%%{KVERREL}%{?1:\.%{1}}(\.debug)?' -o debuginfo%{?1}.list}\
%{nil}

#
# This macro creates a kernel-<subpackage>-devel package.
#	%%kernel_devel_package <subpackage> <pretty-name>
#
%define kernel_devel_package() \
%package %{?1:%{1}-}devel\
Summary: Development package for building kernel modules to match the %{?2:%{2} }kernel\
Group: System Environment/Kernel\
Provides: installonlypkg(kernel-rt-devel) = %{version}-%{release}%{?1:.%{1}}\
Provides: kernel-rt%{?1:-%{1}}-devel-%{_target_cpu} = %{version}-%{release}\
Provides: kernel-rt-devel-%{_target_cpu} = %{version}-%{release}%{?1:.%{1}}\
Provides: kernel-rt-devel-uname-r = %{KVERREL}%{?1:.%{1}}\
AutoReqProv: no\
Requires(pre): /usr/bin/find\
%description -n kernel-rt%{?variant}%{?1:-%{1}}-devel\
This package provides kernel headers and makefiles sufficient to build modules\
against the %{?2:%{2} }kernel package.\
%{nil}

#
# This macro creates a kernel-<subpackage> and its -devel and -debuginfo too.
#	%%define variant_summary The Linux kernel compiled for <configuration>
#	%%kernel_variant_package [-n <pretty-name>] <subpackage>
#
%define kernel_variant_package(n:) \
%package %1\
Summary: %{variant_summary}\
Group: System Environment/Kernel\
%kernel_reqprovconf\
%{expand:%%kernel_devel_package %1 %{!?-n:%1}%{?-n:%{-n*}}}\
%{expand:%%kernel_debuginfo_package %1}\
%{expand:%%kernel_kvm_package %1}\
%{expand:%%kernel_kvm_debuginfo_package %1}\
%{nil}


# First the auxiliary packages of the main kernel package.
%kernel_devel_package
%kernel_debuginfo_package

%if %{signmodules}
cp %{SOURCE19} .
cat <<EOF
###
### Now generating a PGP key pair to be used for signing modules.
###
### If this takes a long time, you might wish to run rngd in the background to
### keep the supply of entropy topped up.  It needs to be run as root, and
### should use a hardware random number generator if one is available, eg:
###
###     rngd -r /dev/hwrandom
###
### If one isn't available, the pseudo-random number generator can be used:
###
###     rngd -r /dev/urandom
###
EOF
gpg --homedir . --batch --gen-key %{SOURCE31}
cat <<EOF
###
### Key pair generated.
###
EOF
# if there're external keys to be included
if [ -s %{SOURCE19} ]; then
	gpg --homedir . --no-default-keyring --keyring kernel.pub --import %{SOURCE19}
fi
gpg --homedir . --export --keyring ./kernel.pub CentOS > extract.pub
gcc -o scripts/bin2c scripts/bin2c.c
mkdir crypto/signature
scripts/bin2c ksign_def_public_key __initdata <extract.pub >crypto/signature/key.h
%endif

# create the production kvm module package
%kernel_kvm_package
%kernel_kvm_debuginfo_package

# Now, each variant package.

%if %{with debug}
# kernel-rt-debug
%define variant_summary The Linux kernel compiled with extra debugging enabled
%kernel_variant_package debug
%description debug
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.
%endif

%if %{with trace}
# kernel-rt-trace
%define variant_summary The Linux kernel compiled with extra tracing options enabled
%kernel_variant_package trace
%description trace
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

This variant of the kernel has numerous tracing options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.
%endif

%if %{with vanilla}
# kernel-rt-vanilla
%define variant_summary The Linux kernel compiled without RT capabilities for debugging
%kernel_variant_package vanilla
%description vanilla
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

This variant of the kernel has the realtime capabilities disabled, but
has a configuration close to the one used in the realtime kernel.
It should only be installed when trying to gather additional information
on kernel bugs.
%endif

%prep
## ApplyPatch routine
patch_command='patch -p1 -F1 -s'
ApplyPatch()
{
local patch=$1
shift
if [ ! -f $RPM_SOURCE_DIR/$patch ]; then
echo "Can't find $RPM_SOURCE_DIR/$patch"
exit 1;
fi
case "$patch" in
*.bz2) bunzip2 < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
*.gz) gunzip < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
*.xz) unxz <  "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
*) $patch_command ${1+"$@"} < "$RPM_SOURCE_DIR/$patch" ;;
esac
}

# we don't want a .config file when building firmware: it just confuses the build system
%define build_firmware \
   # mv .config .config.firmware_save \
   make INSTALL_FW_PATH=$RPM_BUILD_ROOT/lib/firmware/%{rpmversion}-%{pkg_release} firmware_install \
   # mv .config.firmware_save .config \
   ln -s /lib/firmware/%{rpmversion}-%{pkg_release} $RPM_BUILD_ROOT/lib/firmware/%{rpmversion}-%{pkg_release}.i686 \
   ln -s /lib/firmware/%{rpmversion}-%{pkg_release} $RPM_BUILD_ROOT/lib/firmware/%{rpmversion}-%{pkg_release}.x86_64 \
   for kvname in debug trace; do \
      ln -s /lib/firmware/%{rpmversion}-%{pkg_release} $RPM_BUILD_ROOT/lib/firmware/%{rpmversion}-%{pkg_release}.i686.$kvname \
      ln -s /lib/firmware/%{rpmversion}-%{pkg_release} $RPM_BUILD_ROOT/lib/firmware/%{rpmversion}-%{pkg_release}.x86_64.$kvname \
   done \
   # install firmware files for bfa 3.1.2.1 \
   pushd $RPM_BUILD_ROOT/lib/firmware/%{rpmversion}-%{pkg_release} \
   popd


if [ ! -d kernel-%{kversion}/vanilla-%{kversion}/ ]; then
	rm -f pax_global_header;
%setup -q -n kernel-%{kversion} -c
	mv %{name}-%{rpmversion}-%{pkg_release_simple} vanilla-%{kversion};
else
	cd kernel-%{kversion}/;
fi

if [ -d linux-%{kversion}.%{_target_cpu} ]; then
  # Just in case we ctrl-c'd a prep already
  rm -rf deleteme.%{_target_cpu}
  # Move away the stale away, and delete in background.
  mv linux-%{kversion}.%{_target_cpu} deleteme.%{_target_cpu}
  rm -rf deleteme.%{_target_cpu} &
fi

if [ -L vanilla-%{kversion}/configs ]; then
        rm -f vanilla-%{kversion}/configs
        mkdir vanilla-%{kversion}/configs
fi

cp -rl vanilla-%{kversion} linux-%{kversion}.%{_target_cpu}

cd linux-%{kversion}.%{_target_cpu}

## Apply Patches here
ApplyPatch debrand-single-cpu.patch
ApplyPatch debrand-rh_taint.patch
ApplyPatch debrand-rh-i686-cpu.patch
ApplyPatch linux-kernel-test.patch

# move off upstream version mechanism
if [ -e localversion-rt ]; then
   mv -f localversion-rt upstream-localversion-rt
fi

# Any further pre-build tree manipulations happen here.

chmod +x scripts/checkpatch.pl

# only deal with configs if we are going to build for the arch
%ifnarch %nobuildarches

# copy the configurations files here
cp %{SOURCE50} %{SOURCE51} %{SOURCE52} .

# now run oldconfig over all the config files
for i in *.config
do
  mv $i .config
  Arch=`head -1 .config | cut -b 3-`
  make %{?cross_opts} ARCH=$Arch listnewconfig | grep -E '^CONFIG_' >.newoptions || true
%if %{listnewconfig_fail}
  if [ -s .newoptions ]; then
    cat .newoptions
    exit 1
  fi
%endif
  rm -f .newoptions
  make %{?cross_opts} ARCH=$Arch oldnoconfig
  echo "# $Arch" > configs/$i
  cat .config >> configs/$i
done
# end of kernel config
%endif

# get rid of unwanted files resulting from patch fuzz
find . \( -name "*.orig" -o -name "*~" \) -exec rm -f {} \; >/dev/null

# remove unnecessary SCM files
find . -name .gitignore -exec rm -f {} \; >/dev/null

cd ..

###
### build
###
%build

%if %{with_sparse}
%global sparse_mflags	C=1
%endif

%if %{fancy_debuginfo}
# This override tweaks the kernel makefiles so that we run debugedit on an
# object before embedding it.  When we later run find-debuginfo.sh, it will
# run debugedit again.  The edits it does change the build ID bits embedded
# in the stripped object, but repeating debugedit is a no-op.  We do it
# beforehand to get the proper final build ID bits into the embedded image.
# This affects the vDSO images in vmlinux, and the vmlinux image in bzImage.
export AFTER_LINK=\
'sh -xc "/usr/lib/rpm/debugedit -b $$RPM_BUILD_DIR -d /usr/src/debug \
				-i $@ > $@.id"'
%endif

cp_vmlinux()
{
  eu-strip --remove-comment -o "$2" "$1"
}

BuildKernel() {
    MakeTarget=$1
    KernelImage=$2
    Flavour=$3
    InstallName=${4:-vmlinuz}

    # Pick the right config file for the kernel we're building
    suffix=
    if [ "$Flavour" != "" ]
    then
	suffix="-${Flavour}"
    fi
    Config=kernel-%{kversion}-%{_target_cpu}-rt${suffix}.config
    DevelDir=/usr/src/kernels/%{KVERREL}${Flavour:+.${Flavour}}

    # When the bootable image is just the ELF kernel, strip it.
    # We already copy the unstripped file into the debuginfo package.
    if [ "$KernelImage" = vmlinux ]; then
      CopyKernel=cp_vmlinux
    else
      CopyKernel=cp
    fi

    KernelVer=%{version}-%{release}.%{_target_cpu}${Flavour:+.${Flavour}}
    echo BUILDING A KERNEL FOR ${Flavour} %{_target_cpu}...

    # make sure EXTRAVERSION says what we want it to say
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}.%{_target_cpu}${Flavour:+.${Flavour}}/" Makefile

    # if pre-rc1 devel kernel, must fix up SUBLEVEL for our versioning scheme
    %if !0%{?rcrev}
    %if 0%{?gitrev}
    perl -p -i -e 's/^SUBLEVEL.*/SUBLEVEL = %{upstream_sublevel}/' Makefile
    %endif
    %endif

    # and now to start the build process

    make -s mrproper

    cp configs/$Config .config
    echo USING CONFIG configs/$Config

    Arch=`head -1 .config | cut -b 3-`
    echo USING ARCH=$Arch

    # hack to help solving the debuginfo hash collision
    export KernelVer

    make -s %{?cross_opts} ARCH=$Arch %{oldconfig_target} > /dev/null
    make -s %{?cross_opts} ARCH=$Arch %{?verbose} %{?_smp_mflags} KCFLAGS="%{?kcflags}" WITH_GCOV="%{?with_gcov}" $MakeTarget %{?sparse_mflags}
    if [ "$Flavour" != "kdump" ]; then
        make -s %{?cross_opts} ARCH=$Arch %{?verbose} %{?_smp_mflags} KCFLAGS="%{?kcflags}" WITH_GCOV="%{?with_gcov}" modules %{?sparse_mflags} || exit 1
    fi

%if %{buildrt}
%if %{buildperf}
    if [ -z "$Flavour" ]; then
        pushd tools/perf
        chmod +x util/generate-cmdlist.sh util/PERF-VERSION-GEN
        ### make -s %{?_smp_mflags} %{?verbose} DESTDIR=$RPM_BUILD_ROOT prefix=/usr install
        make -s %{?verbose} %{?_smp_mflags} NO_DEMANGLE=1 perf
        mkdir -p $RPM_BUILD_ROOT/usr/libexec/
        install -m 755 perf $RPM_BUILD_ROOT/usr/libexec/perf.%{KVERREL}%{?Flavour:+.%{Flavour}}
        popd
    fi
%endif
%endif

    # Start installing the results
%if %{builddebuginfo}
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/boot
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/%{image_install_path}
    install -m 644 System.map $RPM_BUILD_ROOT/%{debuginfodir}/boot/System.map-$KernelVer
%endif
    mkdir -p $RPM_BUILD_ROOT/%{image_install_path}
    install -m 644 .config $RPM_BUILD_ROOT/boot/config-$KernelVer
    install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-$KernelVer
%if %{use_dracut}
    # We estimate the size of the initramfs because rpm needs to take this size
    # into consideration when performing disk space calculations. (See bz #530778)
    dd if=/dev/zero of=$RPM_BUILD_ROOT/boot/initramfs-$KernelVer.img bs=1M count=20
%else
    dd if=/dev/zero of=$RPM_BUILD_ROOT/boot/initrd-$KernelVer.img bs=1M count=5
%endif
    if [ -f arch/$Arch/boot/zImage.stub ]; then
      cp arch/$Arch/boot/zImage.stub $RPM_BUILD_ROOT/%{image_install_path}/zImage.stub-$KernelVer || :
    fi
# EFI SecureBoot signing, x86_64-only
%ifarch x86_64
    %pesign -s -i $KernelImage -o $KernelImage.signed -a %{SOURCE33} -c %{SOURCE33} 
    mv $KernelImage.signed $KernelImage
%endif
    $CopyKernel $KernelImage $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    chmod 755 $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer

    # hmac sign the kernel for FIPS
    echo "Creating hmac file: $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac"
    ls -l $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    sha512hmac $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer | sed -e "s,$RPM_BUILD_ROOT,," > $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac;

    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/kernel
    if [ "$Flavour" != "kdump" ]; then
        # Override $(mod-fw) because we don't want it to install any firmware
        # we'll get it from the linux-firmware package and we don't want conflicts
        make -s %{?cross_opts} ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT modules_install KERNELRELEASE=$KernelVer mod-fw=
    fi
%ifarch %{vdso_arches}
    make -s %{?cross_opts} ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT vdso_install KERNELRELEASE=$KernelVer
    if [ ! -s ldconfig-kernel.conf ]; then
      echo > ldconfig-kernel.conf "\
# Placeholder file, no vDSO hwcap entries used in this kernel."
    fi
    %{__install} -D -m 444 ldconfig-kernel.conf \
        $RPM_BUILD_ROOT/etc/ld.so.conf.d/kernel-rt-$KernelVer.conf
%endif

    # And save the headers/makefiles etc for building modules against
    #
    # This all looks scary, but the end result is supposed to be:
    # * all arch relevant include/ files
    # * all Makefile/Kconfig files
    # * all script/ files

    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/source
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    (cd $RPM_BUILD_ROOT/lib/modules/$KernelVer ; ln -s build source)
    # dirs for additional modules per module-init-tools, kbuild/modules.txt
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/extra
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/updates
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/weak-updates
    # first copy everything
    cp --parents `find  -type f -name "Makefile*" -o -name "Kconfig*"` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    # now nuke the MRG directory
    # TODO: figure out of we need this or not
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/MRG

    cp Module.symvers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp System.map $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ -s Module.markers ]; then
      cp Module.markers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    fi

    # then drop all but the needed Makefiles/Kconfig files
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Documentation
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ -d arch/$Arch/scripts ]; then
      cp -a arch/$Arch/scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch} || :
    fi
    if [ -f arch/$Arch/*lds ]; then
      cp -a arch/$Arch/*lds $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch}/ || :
    fi
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*.o
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*/*.o

    # hack to remove .build-id conflict with RHEL kernel debuginfo
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/conmakehash
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/pnmtologo

    if [ -d arch/%{asmarch}/include ]; then
      cp -a --parents arch/%{asmarch}/include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    fi
    cp -a include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include

    # copy objtool for kernel-rt-devel (needed for building external modules)
    if grep -q CONFIG_STACK_VALIDATION=y .config; then
      mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/tools/objtool
      cp -a tools/objtool/objtool $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/tools/objtool
    fi

    # Make sure the Makefile and version.h have a matching timestamp so that
    # external modules can be built
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/generated/uapi/linux/version.h
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/generated/autoconf.h
    # Copy .config to include/config/auto.conf so "make prepare" is unnecessary.
    cp $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/config/auto.conf

    #
    # save the vmlinux file for kernel debugging into the kernel-debuginfo rpm
    #
%if %{builddebuginfo}
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
    cp vmlinux $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
%endif

    find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" -type f >modnames

    # mark modules executable so that strip-to-file can strip them
    xargs --no-run-if-empty chmod u+x < modnames

    # Generate a list of modules for block and networking.

    grep -F /drivers/ modnames | xargs --no-run-if-empty nm -upA |
    sed -n 's,^.*/\([^/]*\.ko\):  *U \(.*\)$,\1 \2,p' > drivers.undef

    collect_modules_list()
    {
      sed -r -n -e "s/^([^ ]+) \\.?($2)\$/\\1/p" drivers.undef |
      LC_ALL=C sort -u > $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$1
      if [ ! -z "$3" ]; then
        sed -r -e "/^($3)\$/d" -i $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$1
      fi
    }

    collect_modules_list networking 'register_netdev|ieee80211_register_hw|usbnet_probe|phy_driver_register|rt2x00(pci|usb)_probe|register_netdevice'
    collect_modules_list block 'ata_scsi_ioctl|scsi_add_host|scsi_add_host_with_dma|blk_alloc_queue|blk_init_queue|register_mtd_blktrans|scsi_esp_register|scsi_register_device_handler|blk_queue_physical_block_size' 'pktcdvd.ko|dm-mod.ko'
    collect_modules_list drm 'drm_open|drm_init'
    collect_modules_list modesetting 'drm_crtc_init'
    collect_modules_list kvm 'kvm_init'

    # detect missing or incorrect license tags
    rm -f modinfo
    while read i
    do
      echo -n "${i#$RPM_BUILD_ROOT/lib/modules/$KernelVer/} " >> modinfo
      /sbin/modinfo -l $i >> modinfo
    done < modnames

    grep -E -v 'GPL( v2)?$|Dual BSD/GPL$|Dual MPL/GPL$|GPL and additional rights$' modinfo && exit 1

    rm -f modinfo modnames

    # Save off the .tmp_versions/ directory.  We'll use it in the
    # __debug_install_post macro below to sign the right things
    # Also save the signing keys so we actually sign the modules with the
    # right key.
    cp -r .tmp_versions .tmp_versions.sign${Flavour:+.${Flavour}}
    cp signing_key.priv signing_key.priv.sign${Flavour:+.${Flavour}}
    cp signing_key.x509 signing_key.x509.sign${Flavour:+.${Flavour}}

    # remove files that will be auto generated by depmod at rpm -i time
    for i in alias alias.bin builtin.bin ccwmap dep dep.bin ieee1394map inputmap isapnpmap ofmap pcimap seriomap symbols symbols.bin usbmap softdep devname
    do
      rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$i
    done

    # Move the devel headers out of the root file system
    mkdir -p $RPM_BUILD_ROOT/usr/src/kernels
    mv $RPM_BUILD_ROOT/lib/modules/$KernelVer/build $RPM_BUILD_ROOT/$DevelDir
    ln -sf ../../../..$DevelDir $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    # copy Module.symvers
    cp Module.symvers $RPM_BUILD_ROOT/$DevelDir

    # prune junk from kernel-devel
    find $RPM_BUILD_ROOT/usr/src/kernels -name ".*.cmd" -exec rm -f {} \;
}

###
# DO it...
###

# prepare directories
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/boot

cd linux-%{kversion}.%{_target_cpu}

# Bugzilla: 1209952
#
# Commit 32b3809 broke the manual kernel build because it depended on
# variables set in the specfile during the RPM build process.
#
# Commit 32b3809 was reverted and the new solution will be applying
# those changes at the %build section of the specfile.
patch -p1 < $RPM_SOURCE_DIR/avoid-debuginfo-hash-collision-scripts.patch

%if %{builddebug}
BuildKernel %make_target %kernel_image debug
%endif

%if %{buildtrace}
BuildKernel %make_target %kernel_image trace
%endif

%if %{buildvanilla}
BuildKernel %make_target %kernel_image vanilla
%endif

# maybe %if %{buildrt}
%if %{buildrt}
BuildKernel %make_target %kernel_image
%endif

%if %{builddoc}
# Make the HTML and man pages.
make -j1 htmldocs mandocs || %{doc_build_fail}

# sometimes non-world-readable files sneak into the kernel source tree
chmod -R a=rX Documentation
find Documentation -type d | xargs chmod u+w
%endif

%if %{buildrt}
%if %{buildperf}
pushd tools/perf
make %{?_smp_mflags} man || %{doc_build_fail}
popd
%endif
%endif
# In the modsign case, we do 3 things.  1) We check the "flavour" and hard
# code the value in the following invocations.  This is somewhat sub-optimal
# but we're doing this inside of an RPM macro and it isn't as easy as it
# could be because of that.  2) We restore the .tmp_versions/ directory from
# the one we saved off in BuildKernel above.  This is to make sure we're
# signing the modules we actually built/installed in that flavour.  3) We
# grab the arch and invoke 'make modules_sign' and the mod-extra-sign.sh
# commands to actually sign the modules.
#
# We have to do all of those things _after_ find-debuginfo runs, otherwise
# that will strip the signature off of the modules.
#
# Finally, pick a module at random and check that it's signed and fail the build
# if it isn't.

%ifnarch noarch
%define __modsign_install_post \
   if [ "%{with_rt}" -ne "0" ]; then \
      Arch=`head -1 configs/kernel-%{version}-%{_target_cpu}-rt.config | cut -b 3-` \
      rm -rf .tmp_versions \
      mv .tmp_versions.sign .tmp_versions \
      mv signing_key.priv.sign signing_key.priv \
      mv signing_key.x509.sign signing_key.x509 \
      %{modsign_cmd} $RPM_BUILD_ROOT/lib/modules/%{KVERREL} || exit 1 \
   fi\
   for AAA in %{?with_trace:trace} %{?with_debug:debug} %{?with_vanilla:vanilla}; do \
      Arch=`head -1 configs/kernel-%{version}-%{_target_cpu}-rt-${AAA}.config | cut -b 3-` \
      rm -rf .tmp_versions \
      mv .tmp_versions.sign.${AAA} .tmp_versions \
      mv signing_key.priv.sign.${AAA} signing_key.priv \
      mv signing_key.x509.sign.${AAA} signing_key.x509 \
      %{modsign_cmd} $RPM_BUILD_ROOT/lib/modules/%{KVERREL}.${AAA} || exit 1 \
   done \
%{nil}
%endif

###
### Special hacks for debuginfo subpackages.
###

# This macro is used by %%install, so we must redefine it before that.
%global debug_package %{nil}

%if %{fancy_debuginfo}
%define __debug_install_post \
  /usr/lib/rpm/find-debuginfo.sh %{debuginfo_args} %{_builddir}/%{?buildsubdir}\
%{nil}
%endif

%if %{builddebuginfo}
%ifnarch noarch
%global __debug_package 1
%files -f debugfiles.list debuginfo-common-%{_target_cpu}
%defattr(-,root,root)
%endif
%endif

#
# Disgusting hack alert! We need to ensure we sign modules *after* all
# invocations of strip occur, which is in __debug_install_post if
# find-debuginfo.sh runs, and __os_install_post if not.
#
%ifnarch noarch
%define __spec_install_post \
  %{?__debug_package:%{__debug_install_post}}\
  %{__arch_install_post}\
  %{__os_install_post}\
  %{__modsign_install_post}\
%{nil}
%endif

###
### install
###

%install
# for some reason, on RHEL-5 RPM_BUILD_ROOT doesn't get set
if [ -z "$RPM_BUILD_ROOT" ]; then
	export RPM_BUILD_ROOT="%{buildroot}";
fi

cd linux-%{kversion}.%{_target_cpu}

%if %{builddoc}
docdir=$RPM_BUILD_ROOT%{_datadir}/doc/kernel-rt-doc-%{rpmversion}
man9dir=$RPM_BUILD_ROOT%{_datadir}/man/man9rt

# copy the source over
mkdir -p $docdir
tar -f - --exclude=man --exclude='.*' --exclude=*.xml --exclude=*.tmpl -c Documentation | tar xf - -C $docdir

# Install man pages for the kernel API.
mkdir -p $man9dir
find Documentation/DocBook/man -name '*.9.gz' -print0 |
xargs -0 --no-run-if-empty %{__install} -m 444 -t $man9dir $m
ls $man9dir | grep -q '' || > $man9dir/BROKEN
%endif # builddoc

# perf docs
%if %{buildrt}
%if %{buildperf}
mandir=$RPM_BUILD_ROOT%{_datadir}/man
man1dir=$mandir/man1
pushd tools/perf/Documentation
make install-man mandir=$mandir
popd

pushd $man1dir
for d in *.1; do
 gzip $d;
done
popd

# perf shell wrapper
mkdir -p $RPM_BUILD_ROOT/usr/sbin/
cp $RPM_SOURCE_DIR/perf $RPM_BUILD_ROOT/usr/sbin/perf
chmod 0755 $RPM_BUILD_ROOT/usr/sbin/perf
cp $RPM_SOURCE_DIR/perf-archive $RPM_BUILD_ROOT/usr/sbin/perf-archive
chmod 0755 $RPM_BUILD_ROOT/usr/sbin/perf-archive
mkdir -p $RPM_BUILD_ROOT%{_datadir}/doc/perf
%endif # buildperf
%endif

%if %{buildheaders}
# Install kernel headers
make ARCH=%{hdrarch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_install

# Do headers_check but don't die if it fails.
make ARCH=%{hdrarch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_check \
     > hdrwarnings.txt || :
if grep -q exist hdrwarnings.txt; then
   sed s:^$RPM_BUILD_ROOT/usr/include/:: hdrwarnings.txt
   # Temporarily cause a build failure if header inconsistencies.
   # exit 1
fi

find $RPM_BUILD_ROOT/usr/include \
     \( -name .install -o -name .check -o \
     	-name ..install.cmd -o -name ..check.cmd \) | xargs rm -f

# glibc provides scsi headers for itself, for now
rm -rf $RPM_BUILD_ROOT/usr/include/scsi
rm -f $RPM_BUILD_ROOT/usr/include/asm*/atomic.h
rm -f $RPM_BUILD_ROOT/usr/include/asm*/io.h
rm -f $RPM_BUILD_ROOT/usr/include/asm*/irq.h
%endif

%if %{buildfirmware}
%{build_firmware}
mkdir -p $RPM_BUILD_ROOT%{_datadir}/doc/kernel-rt-%{rpmversion}-%{pkg_release}/firmware
cp firmware/WHENCE $RPM_BUILD_ROOT%{_datadir}/doc/kernel-rt-%{rpmversion}-%{pkg_release}/firmware
%endif

###
### clean
###

%clean
rm -rf $RPM_BUILD_ROOT

###
### scripts
###

#
# This macro defines a %%post script for a kernel*-devel package.
#	%%kernel_devel_post [<subpackage>]
#
%define kernel_devel_post() \
%{expand:%%post %{?1:%{1}-}devel}\
if [ -f /etc/sysconfig/kernel ]\
then\
    . /etc/sysconfig/kernel || exit $?\
fi\
if [ "$HARDLINK" != "no" -a -x /usr/sbin/hardlink ]\
then\
    (cd /usr/src/kernels/%{KVERREL}%{?1:.%{1}} &&\
     /usr/bin/find . -type f | while read f; do\
       hardlink -c /usr/src/kernels/*.fc*.*/$f $f\
     done)\
fi\
%{nil}

# This macro defines a %%posttrans script for a kernel package.
#	%%kernel_variant_posttrans [<subpackage>]
# More text can follow to go at the end of this variant's %%post.
#
# grubby might be called during installation when a boot loader configuration
# file is not present, so just drop any error messages. See BZ#610813 for
# more details.
%define kernel_variant_posttrans() \
%{expand:%%posttrans %{?1}}\
%{expand:\
NEWKERNARGS=""\
(/sbin/grubby --info=`/sbin/grubby --default-kernel`) 2>/dev/null | grep -q crashkernel\
if [ $? -ne 0 ]\
then\
	NEWKERNARGS="--kernel-args=\"crashkernel=auto\""\
fi\
NKPARGS="--mkinitrd --depmod --update"\
%if %{use_dracut}\
NKPARGS="$NKPARGS --dracut"\
%endif\
/sbin/new-kernel-pkg --package kernel-rt $NKPARGS %{KVERREL}%{?1:.%{1}} $NEWKERNARGS || exit $?\
}\
/sbin/new-kernel-pkg --package kernel-rt --rpmposttrans %{KVERREL}%{?1:.%{1}} || exit $?\
%{nil}

#
# This macro defines a %%post script for a kernel package and its devel package.
#	%%kernel_variant_post [-v <subpackage>] [-r <replace>]
# More text can follow to go at the end of this variant's %%post.
#
%define kernel_variant_post(v:r:) \
%{expand:%%kernel_devel_post %{?-v*}}\
%{expand:%%kernel_variant_posttrans %{?-v*}}\
%{expand:%%post %{?-v*}}\
%{expand:\
/sbin/new-kernel-pkg --package kernel-rt %{!?-v:--make-default} --install %{KVERREL}%{?-v:.%{-v*}} || exit $?\
}\
[ -d /lib/firmware/updates ] || mkdir -p /lib/firmware/updates\
ln -sf /lib/firmware/mrg-rt-firmware /lib/firmware/updates/%{KVERREL}%{?1:.%{1}}\
%{nil}

# This macro defines a %%post script for a kernel-rt-kvm package.
#	%%kernel_kvm_variant_post <subpackage>
#
%define kernel_kvm_variant_post() \
%{expand:%%post %{?1:%{1}-}kvm}\
depmod %{KVERREL}%{?1:.%{1}} || exit $?\
%{nil}

# This macro defines a %%preun script for a kernel package.
#	%%kernel_variant_preun <subpackage>
#
%define kernel_variant_preun() \
%{expand:%%preun %{?1}}\
/sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}%{?1:.%{1}} || exit $?\
%{nil}

# This macro defines a %%postun script for a kernel-rt-kvm package.
#	%%kernel_kvm_variant_postun <subpackage>
#
%define kernel_kvm_variant_postun() \
%{expand:%%postun %{?1:%{1}-}kvm}\
depmod %{KVERREL}%{?1:.%{1}} || exit $?\
%{nil}

%kernel_variant_preun
%kernel_variant_post
%kernel_kvm_variant_post
%kernel_kvm_variant_postun

%if %{with debug}
# kernel-rt-debug %post script
%kernel_variant_preun debug
%kernel_variant_post -v debug
%kernel_kvm_variant_post debug
%kernel_kvm_variant_postun debug
%endif

%if %{with trace}
# kernel-rt-trace %post script
%kernel_variant_preun trace
%kernel_variant_post -v trace
%kernel_kvm_variant_post trace
%kernel_kvm_variant_postun trace
%endif

%if %{with vanilla}
# kernel-rt-vanilla %post script
%kernel_variant_preun vanilla
%kernel_variant_post -v vanilla
%kernel_kvm_variant_post vanilla
%kernel_kvm_variant_postun vanilla
%endif

if [ -x /sbin/ldconfig ]
then
    /sbin/ldconfig -X || exit $?
fi

###
### file lists
###

%if %{buildheaders}
%files headers
%defattr(-,root,root)
/usr/include/*
%endif

%if %{buildfirmware}
%files firmware
%defattr(-,root,root)
/lib/firmware/*
%doc %{_datadir}/doc/kernel-rt-%{rpmversion}-%{pkg_release}/firmware/WHENCE
%endif

# only some architecture builds need kernel-doc
%if %{builddoc}
%files doc
%defattr(-,root,root)
%{_datadir}/doc/kernel-rt-doc-%{rpmversion}/Documentation/*
%dir %{_datadir}/doc/kernel-rt-doc-%{rpmversion}/Documentation
%dir %{_datadir}/doc/kernel-rt-doc-%{rpmversion}
%{_datadir}/man/man9rt/*
%endif

%if %{buildrt}
%if %{buildperf}
%files -n perf-rt
%defattr(-,root,root)
/usr/sbin/perf
/usr/sbin/perf-archive
/usr/libexec/*
%{_datadir}/man/man1/*
%{_datadir}/doc/perf
%endif
%endif

# This is %{image_install_path} on an arch where that includes ELF files,
# or empty otherwise.
%global elf_image_install_path %{?kernel_image_elf:%{image_install_path}}

#
# This macro defines the %%files sections for a kernel package
# and its devel and debuginfo packages.
#	%%kernel_variant_files [-k vmlinux] <condition> <subpackage>
#
%define kernel_variant_files(k:) \
%if %{1}\
%{expand:%%files %{?2}}\
%defattr(-,root,root)\
/%{image_install_path}/%{?-k:%{-k*}}%{!?-k:vmlinuz}-%{KVERREL}%{?2:.%{2}}\
/%{image_install_path}/.vmlinuz-%{KVERREL}%{?2:.%{2}}.hmac\
/boot/System.map-%{KVERREL}%{?2:.%{2}}\
/boot/config-%{KVERREL}%{?2:.%{2}}\
%exclude /lib/modules/%{KVERREL}%{?2:.%{2}}/kernel/arch/x86/kvm\
%exclude /lib/modules/%{KVERREL}%{?2:.%{2}}/modules.kvm\
%dir /lib/modules/%{KVERREL}%{?2:.%{2}}\
/lib/modules/%{KVERREL}%{?2:.%{2}}/kernel\
/lib/modules/%{KVERREL}%{?2:.%{2}}/extra\
/lib/modules/%{KVERREL}%{?2:.%{2}}/build\
/lib/modules/%{KVERREL}%{?2:.%{2}}/source\
/lib/modules/%{KVERREL}%{?2:.%{2}}/updates\
/lib/modules/%{KVERREL}%{?2:.%{2}}/weak-updates\
%ifarch %{vdso_arches}\
/lib/modules/%{KVERREL}%{?2:.%{2}}/vdso\
/etc/ld.so.conf.d/kernel-rt-%{KVERREL}%{?2:.%{2}}.conf\
%endif\
/lib/modules/%{KVERREL}%{?2:.%{2}}/modules.*\
%if %{use_dracut}\
%ghost /boot/initramfs-%{KVERREL}%{?2:.%{2}}.img\
%else\
%ghost /boot/initrd-%{KVERREL}%{?2:.%{2}}.img\
%endif\
%{expand:%%files %{?2:%{2}-}devel}\
%defattr(-,root,root)\
%dir /usr/src/kernels\
/usr/src/kernels/%{KVERREL}%{?2:.%{2}}\
%if %{builddebuginfo}\
%ifnarch noarch\
%if %{builddebuginfo}\
%if %{fancy_debuginfo}\
%{expand:%%files -f debuginfo%{?2}.list %{?2:%{2}-}debuginfo}\
%{debuginfodir}/boot/System.map-%{KVERREL}%{?2:.%{2}}\
%else\
%{expand:%%files %{?2:%{2}-}debuginfo}\
%endif\
%endif\
%defattr(-,root,root)\
%if %{builddebuginfo}\
%if !%{fancy_debuginfo}\
%if "%{elf_image_install_path}" != ""\
%{debuginfodir}/%{elf_image_install_path}/*-%{KVERREL}%{?2:.%{2}}.debug\
%endif\
%endif\
%exclude %{debuginfodir}/lib/modules/%{KVERREL}%{?2:.%{2}}/kernel/arch/x86/kvm\
%{debuginfodir}/lib/modules/%{KVERREL}%{?2:.%{2}}\
%{debuginfodir}/usr/src/kernels/%{KVERREL}%{?2:.%{2}}\
%{debuginfodir}/boot/System.map-%{KVERREL}%{?2:.%{2}}\
%endif\
%endif\
%endif\
%endif\
%ifnarch noarch\
%{expand:%%files %{?2:%{2}-}kvm}\
/lib/modules/%{KVERREL}%{?2:.%{2}}/modules.kvm\
/lib/modules/%{KVERREL}%{?2:.%{2}}/kernel/arch/x86/kvm\
%{expand:%%files %{?2:%{2}-}kvm-debuginfo}\
%dir %{debuginfodir}/lib/modules/%{KVERREL}%{?2:.%{2}}/kernel/arch/x86/kvm\
%{debuginfodir}/lib/modules/%{KVERREL}%{?2:.%{2}}/kernel/arch/x86/kvm\
%endif\
%{nil}

%kernel_variant_files %{buildrt}

%if %{builddebug}
%kernel_variant_files %{builddebug} debug
%endif

%if %{buildtrace}
%kernel_variant_files %{buildtrace} trace
%endif

%if %{buildvanilla}
%kernel_variant_files %{buildvanilla} vanilla
%endif

%changelog
* Fri Feb 10 2017 Johnny Hughes <johnny@centos.org> [3.10.0-514.6.1.rt56.429.el7]
- Manual CentOS Debranding

* Wed Dec 14 2016 Clark Williams <williams@redhat.com> [3.10.0-514.6.1.rt56.429.el7]
- [rt] kernel-rt-3.10.0-514.6.1.rt56.429.el7 (Clark Williams) [1401863]
- [rt] specfile changelog cleanup (Clark Williams)

* Tue Dec 13 2016 Clark Williams <williams@redhat.com> [3.10.0-514.6.1.rt56.428.el7]
- [rt] kernel-rt-3.10.0-514.6.1.rt56.428.el7 (Clark Williams) [1401863]

* Tue Dec 13 2016 Clark Williams <williams@redhat.com> [3.10.0-514.6.1.rt56.427.el7]
- [rt] kernel-rt-3.10.0-514.6.1.rt56.427.el7 (Clark Williams) [1377840]

* Thu Dec 08 2016 Clark Williams <williams@redhat.com> [3.10.0-514.5.1.rt56.426.el7]
- [rt] kernel-rt-3.10.0-514.5.1.rt56.426.el7 (Clark Williams) [1377840]
- [rt] net: Always disable irqs in napi_schedule*() (Steven Rostedt) [1402837]

* Mon Dec 05 2016 Clark Williams <williams@redhat.com> [3.10.0-514.5.1.rt56.425.el7]
- [rt] kernel-rt-3.10.0-514.5.1.rt56.425.el7 (Clark Williams) [1377840]
- [rt] dm: Make rt aware (Thomas Gleixner) [1400930]

* Thu Nov 17 2016 Clark Williams <williams@redhat.com> [3.10.0-514.2.2.rt56.424.el7]
- [rt] kernel-rt-3.10.0-514.2.2.rt56.424.el7 (Clark Williams) [1377840]

* Sat Nov 05 2016 Clark Williams <williams@redhat.com> [3.10.0-514.2.1.rt56.423.el7]
- [rt] kernel-rt-3.10.0-514.2.1.rt56.423.el7 (Clark Williams) [1377840]
- specfile: kernel-rt-3.10.0-514.1.1.rt56.422.el7 (Clark Williams)
- [rt] kernel-rt-3.10.0-514.1.1.rt56.422.el7 (Clark Williams) [1377840]

* Wed Nov 02 2016 Clark Williams <williams@redhat.com> [3.10.0-514.1.1.rt56.422.el7]
- [rt] kernel-rt-3.10.0-514.1.1.rt56.422.el7 (Clark Williams) [1377840]

* Tue Nov 01 2016 Clark Williams <williams@redhat.com> [3.10.0-514.1.1.rt56.421.el7]
- [rt] kernel-rt-3.10.0-514.1.1.rt56.421.el7 (Clark Williams) [1377840]
- net: Make synchronize_rcu_expedited() conditional on !RT_FULL (Josh Cartwright) [1378172]

* Wed Oct 19 2016 Clark Williams <williams@redhat.com> [3.10.0-514.rt56.420.el7]
- [rt] kernel-rt-3.10.0-514.rt56.420.el7 (Clark Williams) [1280494]

* Wed Oct 12 2016 Clark Williams <williams@redhat.com> [3.10.0-513.rt56.419.el7]
- [rt] kernel-rt-3.10.0-513.rt56.419.el7 (Clark Williams) [1280494]

* Sat Oct 01 2016 Clark Williams <williams@redhat.com> [3.10.0-512.rt56.418.el7]
- [rt] kernel-rt-3.10.0-512.rt56.418.el7 (Clark Williams) [1280494]

* Fri Sep 30 2016 Clark Williams <williams@redhat.com> [3.10.0-511.rt56.417.el7]
- [rt] kernel-rt-3.10.0-511.rt56.417.el7 (Clark Williams) [1280494]
- time: fix missing 'else' clause in tick_do_update_jiffies64() (Clark Williams) [1327301]

* Thu Sep 29 2016 Clark Williams <williams@redhat.com> [3.10.0-511.rt56.416.el7]
- [rt] kernel-rt-3.10.0-511.rt56.416.el7 (Clark Williams) [1280494]
- [rt] fixed missing patch hunk from rcu stall fix [1292927] (Clark Williams)

* Wed Sep 21 2016 Clark Williams <williams@redhat.com> [3.10.0-510.rt56.415.el7]
- [rt] kernel-rt-3.10.0-510.rt56.415.el7 (Clark Williams) [1280494]

* Tue Sep 20 2016 Clark Williams <williams@redhat.com> [3.10.0-509.rt56.414.el7]
- [rt] kernel-rt-3.10.0-509.rt56.414.el7 (Clark Williams) [1280494]
- [rt] conditionalize swap reference on CONFIG_TRANSPARENT_HUGEPAGE (Clark Williams)

* Mon Sep 19 2016 Clark Williams <williams@redhat.com> [3.10.0-508.rt56.413.el7]
- [rt] kernel-rt-3.10.0-508.rt56.413.el7 (Clark Williams) [1280494]

* Thu Sep 15 2016 Clark Williams <williams@redhat.com> [3.10.0-507.rt56.412.el7]
- [rt] kernel-rt-3.10.0-507.rt56.412.el7 (Clark Williams) [1280494]

* Tue Sep 13 2016 Clark Williams <williams@redhat.com> [3.10.0-506.rt56.411.el7]
- [rt] kernel-rt-3.10.0-506.rt56.411.el7 (Clark Williams) [1280494]

* Mon Sep 12 2016 Clark Williams <williams@redhat.com> [3.10.0-505.rt56.410.el7]
- [rt] kernel-rt-3.10.0-505.rt56.410.el7 (Clark Williams) [1280494]
- fork: avoid thundering herd in tasklist_read_lock() (root) [1374515]
- rtmutex: Make wait_lock irq safe (Thomas Gleixner) [1374515]
- sched/rt: Avoid sending an IPI to a CPU already doing a push (Steven Rostedt)

* Tue Sep 06 2016 Clark Williams <williams@redhat.com> [3.10.0-505.rt56.409.el7]
- [rt] kernel-rt-3.10.0-505.rt56.409.el7 (Clark Williams) [1280494]
- spi: spi-gpio: Fix compiler warning when building for 64 bit systems (Torsten Fleischer)

* Tue Sep 06 2016 Clark Williams <williams@redhat.com> [3.10.0-504.rt56.408.el7]
- [rt] kernel-rt-3.10.0-504.rt56.408.el7 (Clark Williams) [1280494]
- [rt] use per-cpu locked var update in __lru_cache_activate_page() (Clark Williams)

* Mon Sep 05 2016 Clark Williams <williams@redhat.com> [3.10.0-504.rt56.407.el7]
- [rt] kernel-rt-3.10.0-504.rt56.407.el7 (Clark Williams) [1280494]

* Sun Sep 04 2016 Clark Williams <williams@redhat.com> [3.10.0-503.rt56.406.el7]
- [rt] kernel-rt-3.10.0-503.rt56.406.el7 (Clark Williams) [1280494]

* Sat Sep 03 2016 Clark Williams <williams@redhat.com> [3.10.0-503.rt56.405.el7]
- [rt] kernel-rt-3.10.0-503.rt56.405.el7 (Clark Williams) [1280494]

* Fri Sep 02 2016 Clark Williams <williams@redhat.com> [3.10.0-502.rt56.404.el7]
- [rt] kernel-rt-3.10.0-502.rt56.404.el7 (Clark Williams) [1280494]

* Fri Sep 02 2016 Clark Williams <williams@redhat.com> [3.10.0-501.rt56.403.el7]
- [rt] kernel-rt-3.10.0-501.rt56.403.el7 (Clark Williams) [1280494]

* Tue Aug 30 2016 Clark Williams <williams@redhat.com> [3.10.0-500.rt56.402.el7]
- [rt] kernel-rt-3.10.0-500.rt56.402.el7 (Clark Williams) [1280494]

* Tue Aug 30 2016 Clark Williams <williams@redhat.com> [3.10.0-499.rt56.401.el7]
- [rt] kernel-rt-3.10.0-499.rt56.401.el7 (Clark Williams) [1280494]

* Mon Aug 29 2016 Clark Williams <williams@redhat.com> [3.10.0-498.rt56.400.el7]
- [rt] kernel-rt-3.10.0-498.rt56.400.el7 (Clark Williams) [1280494]

* Fri Aug 26 2016 Clark Williams <williams@redhat.com> [3.10.0-497.rt56.399.el7]
- [rt] kernel-rt-3.10.0-497.rt56.399.el7 (Clark Williams) [1280494]

* Fri Aug 26 2016 Clark Williams <williams@redhat.com> [3.10.0-496.rt56.398.el7]
- [rt] kernel-rt-3.10.0-496.rt56.398.el7 (Clark Williams) [1280494]

* Tue Aug 23 2016 Clark Williams <williams@redhat.com> [3.10.0-495.rt56.397.el7]
- [rt] kernel-rt-3.10.0-495.rt56.397.el7 (Clark Williams) [1280494]

* Mon Aug 22 2016 Clark Williams <williams@redhat.com> [3.10.0-494.rt56.396.el7]
- [rt] kernel-rt-3.10.0-494.rt56.396.el7 (Clark Williams) [1280494]

* Wed Aug 17 2016 Clark Williams <williams@redhat.com> [3.10.0-493.rt56.395.el7]
- [rt] kernel-rt-3.10.0-493.rt56.395.el7 (Clark Williams) [1280494]
- [rt] update specfile to make it closer to RHEL logic (Clark Williams) [1367256]

* Wed Aug 17 2016 Clark Williams <williams@redhat.com> [3.10.0-493.rt56.394.el7]
- [rt] kernel-rt-3.10.0-493.rt56.394.el7 (Clark Williams) [1280494]

* Tue Aug 16 2016 Clark Williams <williams@redhat.com> [3.10.0-493.rt56.393.el7]
- [rt] kernel-rt-3.10.0-493.rt56.393.el7 (Clark Williams) [1280494]
- [rt] tracing: clean up hwlat_tracer port (Clark Williams) [1366033]
- tracing: fix hwlat_tracer for RHEL-RT (Clark Williams)

* Mon Aug 15 2016 Clark Williams <williams@redhat.com> [3.10.0-492.rt56.392.el7]
- [rt] kernel-rt-3.10.0-492.rt56.392.el7 (Clark Williams) [1280494]

* Sun Aug 14 2016 Clark Williams <williams@redhat.com> [3.10.0-491.rt56.391.el7]
- [rt] kernel-rt-3.10.0-491.rt56.391.el7 (Clark Williams) [1280494]

* Thu Aug 11 2016 Clark Williams <williams@redhat.com> [3.10.0-490.rt56.390.el7]
- [rt] kernel-rt-3.10.0-490.rt56.390.el7 (Clark Williams) [1280494]

* Thu Aug 11 2016 Clark Williams <williams@redhat.com> [3.10.0-489.rt56.389.el7]
- [rt] kernel-rt-3.10.0-489.rt56.389.el7 (Clark Williams) [1280494]
- tracing: change hwlat to not use trace_handle_return() (Clark Williams) [1366033]
- tracing: Add NMI tracing in hwlat detector ("Steven Rostedt (Red Hat)")
- tracing: Have hwlat trace migrate across tracing_cpumask CPUs ("Steven Rostedt (Red Hat)") [1366033]
- tracing: Add documentation for hwlat_detector tracer (Jon Masters) [1366033]
- tracing: Added hardware latency tracer (Clark Williams) [1366033]

* Mon Aug 08 2016 Clark Williams <williams@redhat.com> [3.10.0-489.rt56.388.el7]
- [rt] kernel-rt-3.10.0-489.rt56.388.el7 (Clark Williams) [1280494]

* Mon Aug 08 2016 Clark Williams <williams@redhat.com> [3.10.0-488.rt56.387.el7]
- [rt] kernel-rt-3.10.0-488.rt56.387.el7 (Clark Williams) [1280494]

* Mon Aug 08 2016 Clark Williams <williams@redhat.com> [3.10.0-487.rt56.386.el7]
- [rt] kernel-rt-3.10.0-487.rt56.386.el7 (Clark Williams) [1280494]

* Mon Aug 08 2016 Clark Williams <williams@redhat.com> [3.10.0-486.rt56.385.el7]
- [rt] kernel-rt-3.10.0-486.rt56.385.el7 (Clark Williams) [1280494]

* Fri Aug 05 2016 Clark Williams <williams@redhat.com> [3.10.0-485.rt56.384.el7]
- [rt] kernel-rt-3.10.0-485.rt56.384.el7 (Clark Williams) [1280494]

* Wed Aug 03 2016 Clark Williams <williams@redhat.com> [3.10.0-484.rt56.383.el7]
- [rt] kernel-rt-3.10.0-484.rt56.383.el7 (Clark Williams) [1280494]

* Wed Aug 03 2016 Clark Williams <williams@redhat.com> [3.10.0-483.rt56.382.el7]
- [rt] kernel-rt-3.10.0-483.rt56.382.el7 (Clark Williams) [1280494]

* Tue Aug 02 2016 Clark Williams <williams@redhat.com> [3.10.0-482.rt56.381.el7]
- [rt] kernel-rt-3.10.0-482.rt56.381.el7 (Clark Williams) [1280494]

* Tue Aug 02 2016 Clark Williams <williams@redhat.com> [3.10.0-482.rt56.380.el7]
- [rt] kernel-rt-3.10.0-482.rt56.380.el7 (Clark Williams) [1280494]

* Wed Jul 27 2016 Clark Williams <williams@redhat.com> [3.10.0-481.rt56.379.el7]
- [rt] kernel-rt-3.10.0-481.rt56.379.el7 (Clark Williams) [1280494]

* Wed Jul 27 2016 Clark Williams <williams@redhat.com> [3.10.0-480.rt56.378.el7]
- [rt] kernel-rt-3.10.0-480.rt56.378.el7 (Clark Williams) [1280494]

* Tue Jul 26 2016 Clark Williams <williams@redhat.com> [3.10.0-479.rt56.377.el7]
- [rt] kernel-rt-3.10.0-479.rt56.377.el7 (Clark Williams) [1280494]

* Sun Jul 24 2016 Clark Williams <williams@redhat.com> [3.10.0-478.rt56.376.el7]
- [rt] kernel-rt-3.10.0-478.rt56.376.el7 (Clark Williams) [1280494]

* Sun Jul 24 2016 Clark Williams <williams@redhat.com> [3.10.0-477.rt56.375.el7]
- [rt] kernel-rt-3.10.0-477.rt56.375.el7 (Clark Williams) [1280494]

* Sun Jul 24 2016 Clark Williams <williams@redhat.com> [3.10.0-476.rt56.374.el7]
- [rt] kernel-rt-3.10.0-476.rt56.374.el7 (Clark Williams) [1280494]

* Sun Jul 24 2016 Clark Williams <williams@redhat.com> [3.10.0-475.rt56.373.el7]
- [rt] kernel-rt-3.10.0-475.rt56.373.el7 (Clark Williams) [1280494]

* Sat Jul 23 2016 Clark Williams <williams@redhat.com> [3.10.0-474.rt56.372.el7]
- [rt] kernel-rt-3.10.0-474.rt56.372.el7 (Clark Williams) [1280494]

* Wed Jul 20 2016 Clark Williams <williams@redhat.com> [3.10.0-473.rt56.371.el7]
- [rt] kernel-rt-3.10.0-473.rt56.371.el7 (Clark Williams) [1280494]

* Wed Jul 20 2016 Clark Williams <williams@redhat.com> [3.10.0-472.rt56.370.el7]
- [rt] kernel-rt-3.10.0-472.rt56.370.el7 (Clark Williams) [1280494]

* Wed Jul 20 2016 Clark Williams <williams@redhat.com> [3.10.0-471.rt56.369.el7]
- [rt] kernel-rt-3.10.0-471.rt56.369.el7 (Clark Williams) [1280494]

* Tue Jul 19 2016 Clark Williams <williams@redhat.com> [3.10.0-470.rt56.368.el7]
- [rt] kernel-rt-3.10.0-470.rt56.368.el7 (Clark Williams) [1280494]
- hpsa: add timeouts for driver initiated commands (Don Brace)

* Mon Jul 18 2016 Clark Williams <williams@redhat.com> [3.10.0-470.rt56.367.el7]
- [rt] kernel-rt-3.10.0-470.rt56.367.el7 (Clark Williams) [1280494]
- [rt] change local_irq_disable to local_irq_disable_nort [1280494] (Clark Williams)
- [rt] fix warning in kernel/smp.c ("Luis Claudio R. Goncalves")

* Sat Jul 16 2016 Clark Williams <williams@redhat.com> [3.10.0-470.rt56.366.el7]
- [rt] kernel-rt-3.10.0-470.rt56.366.el7 (Clark Williams) [1280494]
- kernel/printk: Don't try to print from IRQ/NMI region (Sebastian Andrzej Siewior)

* Fri Jul 15 2016 Clark Williams <williams@redhat.com> [3.10.0-469.rt56.365.el7]
- [rt] kernel-rt-3.10.0-469.rt56.365.el7 (Clark Williams) [1280494]
- printk: make printk rt aware (Thomas Gleixner) [1340922]
- Revert "printk: Make rt aware" (Clark Williams)
- Revert "[rt] printk: change from preempt_disable to migrate_disable" (Clark Williams)

* Fri Jul 15 2016 Clark Williams <williams@redhat.com> [3.10.0-469.rt56.364.el7]
- [rt] kernel-rt-3.10.0-469.rt56.364.el7 (Clark Williams) [1280494]

* Thu Jul 14 2016 Clark Williams <williams@redhat.com> [3.10.0-468.rt56.363.el7]
- [rt] kernel-rt-3.10.0-468.rt56.363.el7 (Clark Williams) [1280494]
- [rt] create inline for do_softirq on PREEMPT_RT_FULL (Clark Williams) [1280494]

* Thu Jul 14 2016 Clark Williams <williams@redhat.com> [3.10.0-468.rt56.362.el7]
- [rt] kernel-rt-3.10.0-468.rt56.362.el7 (Clark Williams) [1280494]

* Thu Jul 14 2016 Clark Williams <williams@redhat.com> [3.10.0-467.rt56.361.el7]
- [rt] kernel-rt-3.10.0-467.rt56.361.el7 (Clark Williams) [1280494]
- [rt] printk: change from preempt_disable to migrate_disable (Clark Williams) [1340922]

* Tue Jul 12 2016 Clark Williams <williams@redhat.com> [3.10.0-467.rt56.360.el7]
- [rt] kernel-rt-3.10.0-467.rt56.360.el7 (Clark Williams) [1280494]

* Tue Jul 12 2016 Clark Williams <williams@redhat.com> [3.10.0-466.rt56.359.el7]
- [rt] kernel-rt-3.10.0-466.rt56.359.el7 (Clark Williams) [1280494]

* Tue Jul 12 2016 Clark Williams <williams@redhat.com> [3.10.0-465.rt56.358.el7]
- [rt] kernel-rt-3.10.0-465.rt56.358.el7 (Clark Williams) [1280494]
- printk: Make rt aware (Thomas Gleixner)
- Revert "printk: Prevent console freeze due to out-of-order deadlock [1269647]" (Clark Williams)
- Revert "printk-rt-aware.patch" (Clark Williams)

* Fri Jul 08 2016 Clark Williams <williams@redhat.com> [3.10.0-464.rt56.357.el7]
- [rt] kernel-rt-3.10.0-464.rt56.357.el7 (Clark Williams) [1280494]

* Fri Jul 08 2016 Clark Williams <williams@redhat.com> [3.10.0-463.rt56.356.el7]
- [rt] kernel-rt-3.10.0-463.rt56.356.el7 (Clark Williams) [1280494]

* Fri Jul 08 2016 Clark Williams <williams@redhat.com> [3.10.0-462.rt56.355.el7]
- [rt] kernel-rt-3.10.0-462.rt56.355.el7 (Clark Williams) [1280494]
- [rt] add PREEMPT_MATCH_TRACE config (Clark Williams) [1353694]
- tracing: Addition of PREEMPT_MATCH_TRACE (Steven Rostedt)

* Thu Jul 07 2016 Clark Williams <williams@redhat.com> [3.10.0-462.rt56.354.el7]
- [rt] kernel-rt-3.10.0-462.rt56.354.el7 (Clark Williams) [1280494]

* Thu Jul 07 2016 Clark Williams <williams@redhat.com> [3.10.0-461.rt56.353.el7]
- [rt] kernel-rt-3.10.0-461.rt56.353.el7 (Clark Williams) [1280494]

* Tue Jul 05 2016 Clark Williams <williams@redhat.com> [3.10.0-461.rt56.352.el7]
- [rt] kernel-rt-3.10.0-461.rt56.352.el7 (Clark Williams) [1280494]

* Fri Jul 01 2016 Clark Williams <williams@redhat.com> [3.10.0-460.rt56.351.el7]
- [rt] kernel-rt-3.10.0-460.rt56.351.el7 (Clark Williams) [1280494]

* Fri Jul 01 2016 Clark Williams <williams@redhat.com> [3.10.0-459.rt56.350.el7]
- [rt] kernel-rt-3.10.0-459.rt56.350.el7 (Clark Williams) [1280494]

* Fri Jul 01 2016 Clark Williams <williams@redhat.com> [3.10.0-458.rt56.349.el7]
- [rt] kernel-rt-3.10.0-458.rt56.349.el7 (Clark Williams) [1280494]

* Thu Jun 30 2016 Clark Williams <williams@redhat.com> [3.10.0-457.rt56.348.el7]
- [rt] kernel-rt-3.10.0-457.rt56.348.el7 (Clark Williams) [1280494]

* Wed Jun 29 2016 Clark Williams <williams@redhat.com> [3.10.0-456.rt56.347.el7]
- [rt] kernel-rt-3.10.0-456.rt56.347.el7 (Clark Williams) [1280494]

* Tue Jun 28 2016 Clark Williams <williams@redhat.com> [3.10.0-455.rt56.346.el7]
- [rt] kernel-rt-3.10.0-455.rt56.346.el7 (Clark Williams) [1280494]
- [rt] enable deadline scheduler module (Clark Williams) [1298387]

* Tue Jun 28 2016 Clark Williams <williams@redhat.com> [3.10.0-455.rt56.345.el7]
- [rt] kernel-rt-3.10.0-455.rt56.345.el7 (Clark Williams) [1280494]

* Mon Jun 27 2016 Clark Williams <williams@redhat.com> [3.10.0-454.rt56.344.el7]
- [rt] kernel-rt-3.10.0-454.rt56.344.el7 (Clark Williams) [1280494]

* Mon Jun 27 2016 Clark Williams <williams@redhat.com> [3.10.0-453.rt56.343.el7]
- [rt] kernel-rt-3.10.0-453.rt56.343.el7 (Clark Williams) [1280494]

* Sun Jun 26 2016 Clark Williams <williams@redhat.com> [3.10.0-452.rt56.342.el7]
- [rt] kernel-rt-3.10.0-452.rt56.342.el7 (Clark Williams) [1280494]

* Fri Jun 24 2016 Clark Williams <williams@redhat.com> [3.10.0-451.rt56.341.el7]
- [rt] kernel-rt-3.10.0-451.rt56.341.el7 (Clark Williams) [1280494]

* Thu Jun 23 2016 Clark Williams <williams@redhat.com> [3.10.0-450.rt56.340.el7]
- [rt] kernel-rt-3.10.0-450.rt56.340.el7 (Clark Williams) [1280494]

* Wed Jun 22 2016 Clark Williams <williams@redhat.com> [3.10.0-449.rt56.339.el7]
- [rt] kernel-rt-3.10.0-449.rt56.339.el7 (Clark Williams) [1280494]

* Wed Jun 22 2016 Clark Williams <williams@redhat.com> [3.10.0-448.rt56.338.el7]
- [rt] kernel-rt-3.10.0-448.rt56.338.el7 (Clark Williams) [1280494]

* Wed Jun 22 2016 Clark Williams <williams@redhat.com> [3.10.0-447.rt56.337.el7]
- [rt] kernel-rt-3.10.0-447.rt56.337.el7 (Clark Williams) [1280494]

* Tue Jun 21 2016 Clark Williams <williams@redhat.com> [3.10.0-446.rt56.336.el7]
- [rt] kernel-rt-3.10.0-446.rt56.336.el7 (Clark Williams) [1280494]

* Tue Jun 21 2016 Clark Williams <williams@redhat.com> [3.10.0-445.rt56.335.el7]
- [rt] kernel-rt-3.10.0-445.rt56.335.el7 (Clark Williams) [1280494]

* Tue Jun 21 2016 Clark Williams <williams@redhat.com> [3.10.0-444.rt56.334.el7]
- [rt] kernel-rt-3.10.0-444.rt56.334.el7 (Clark Williams) [1280494]

* Tue Jun 21 2016 Clark Williams <williams@redhat.com> [3.10.0-443.rt56.333.el7]
- [rt] kernel-rt-3.10.0-443.rt56.333.el7 (Clark Williams) [1280494]
- [rt] fix rt_mutex_init_waiters to initialize rbtree nodes [1280494] (Clark Williams)

* Mon Jun 20 2016 Clark Williams <williams@redhat.com> [3.10.0-443.rt56.332.el7]
- [rt] kernel-rt-3.10.0-443.rt56.332.el7 (Clark Williams) [1280494]
- [rt] fixup RT collisions with SCHED_DEADLINE backport [1280494] (Clark Williams)

* Sat Jun 18 2016 Clark Williams <williams@redhat.com> [3.10.0-442.rt56.331.el7]
- [rt] kernel-rt-3.10.0-442.rt56.331.el7 (Clark Williams) [1280494]

* Fri Jun 17 2016 Clark Williams <williams@redhat.com> [3.10.0-441.rt56.330.el7]
- [rt] kernel-rt-3.10.0-441.rt56.330.el7 (Clark Williams) [1280494]
- Revert "[redhat-rt] update debuginfo hash avoidance patch for the -439 RHEL update" (Clark Williams)

* Fri Jun 17 2016 Clark Williams <williams@redhat.com> [3.10.0-441.rt56.329.el7]
- [rt] kernel-rt-3.10.0-441.rt56.329.el7 (Clark Williams) [1280494]

* Fri Jun 17 2016 Clark Williams <williams@redhat.com> [3.10.0-440.rt56.328.el7]
- [rt] kernel-rt-3.10.0-440.rt56.328.el7 (Clark Williams) [1280494]

* Fri Jun 17 2016 Clark Williams <williams@redhat.com> [3.10.0-439.rt56.327.el7]
- [rt] kernel-rt-3.10.0-439.rt56.327.el7 (Clark Williams) [1280494]

* Thu Jun 16 2016 Clark Williams <williams@redhat.com> [3.10.0-438.rt56.326.el7]
- [rt] kernel-rt-3.10.0-438.rt56.326.el7 (Clark Williams) [1280494]

* Thu Jun 16 2016 Clark Williams <williams@redhat.com> [3.10.0-437.rt56.325.el7]
- [rt] kernel-rt-3.10.0-437.rt56.325.el7 (Clark Williams) [1280494]

* Thu Jun 16 2016 Clark Williams <williams@redhat.com> [3.10.0-436.rt56.324.el7]
- [rt] kernel-rt-3.10.0-436.rt56.324.el7 (Clark Williams) [1280494]

* Wed Jun 15 2016 Clark Williams <williams@redhat.com> [3.10.0-435.rt56.323.el7]
- [rt] kernel-rt-3.10.0-435.rt56.323.el7 (Clark Williams) [1280494]

* Wed Jun 15 2016 Clark Williams <williams@redhat.com> [3.10.0-434.rt56.322.el7]
- [rt] kernel-rt-3.10.0-434.rt56.322.el7 (Clark Williams) [1280494]

* Tue Jun 14 2016 Clark Williams <williams@redhat.com> [3.10.0-433.rt56.321.el7]
- [rt] kernel-rt-3.10.0-433.rt56.321.el7 (Clark Williams) [1280494]
- mm: perform lru_add_drain_all() remotely [1328890] (Luiz Capitulino)
- locallock: add local_lock_on() [1328890] (Sebastian Andrzej Siewior)

* Tue Jun 14 2016 Clark Williams <williams@redhat.com> [3.10.0-433.rt56.320.el7]
- [rt] kernel-rt-3.10.0-433.rt56.320.el7 (Clark Williams) [1280494]
- [rt] mm: allocate 8GB of pages in update_defer_init() [1343797] (Clark Williams)

* Mon Jun 13 2016 Clark Williams <williams@redhat.com> [3.10.0-433.rt56.319.el7]
- [rt] kernel-rt-3.10.0-433.rt56.319.el7 (Clark Williams) [1280494]

* Mon Jun 13 2016 Clark Williams <williams@redhat.com> [3.10.0-432.rt56.318.el7]
- [rt] kernel-rt-3.10.0-432.rt56.318.el7 (Clark Williams) [1280494]

* Mon Jun 13 2016 Clark Williams <williams@redhat.com> [3.10.0-431.rt56.317.el7]
- [rt] kernel-rt-3.10.0-431.rt56.317.el7 (Clark Williams) [1280494]

* Mon Jun 13 2016 Clark Williams <williams@redhat.com> [3.10.0-430.rt56.316.el7]
- [rt] kernel-rt-3.10.0-430.rt56.316.el7 (Clark Williams) [1280494]
- [rt] hpsa: convert hpsa driver to simple waitqueue interface [1280494] (Clark Williams)

* Sun Jun 12 2016 Clark Williams <williams@redhat.com> [3.10.0-430.rt56.315.el7]
- [rt] kernel-rt-3.10.0-430.rt56.315.el7 (Clark Williams) [1280494]

* Sun Jun 12 2016 Clark Williams <williams@redhat.com> [3.10.0-429.rt56.314.el7]
- [rt] kernel-rt-3.10.0-429.rt56.314.el7 (Clark Williams) [1280494]

* Sun Jun 12 2016 Clark Williams <williams@redhat.com> [3.10.0-428.rt56.313.el7]
- [rt] kernel-rt-3.10.0-428.rt56.313.el7 (Clark Williams) [1280494]

* Sun Jun 12 2016 Clark Williams <williams@redhat.com> [3.10.0-427.rt56.312.el7]
- [rt] kernel-rt-3.10.0-427.rt56.312.el7 (Clark Williams) [1280494]

* Sat Jun 11 2016 Clark Williams <williams@redhat.com> [3.10.0-426.rt56.311.el7]
- [rt] kernel-rt-3.10.0-426.rt56.311.el7 (Clark Williams) [1280494]

* Sat Jun 11 2016 Clark Williams <williams@redhat.com> [3.10.0-425.rt56.310.el7]
- [rt] kernel-rt-3.10.0-425.rt56.310.el7 (Clark Williams) [1280494]

* Fri Jun 10 2016 Clark Williams <williams@redhat.com> [3.10.0-424.rt56.309.el7]
- [rt] kernel-rt-3.10.0-424.rt56.309.el7 (Clark Williams) [1280494]

* Fri Jun 10 2016 Clark Williams <williams@redhat.com> [3.10.0-423.rt56.308.el7]
- [rt] kernel-rt-3.10.0-423.rt56.308.el7 (Clark Williams) [1280494]

* Fri Jun 10 2016 Clark Williams <williams@redhat.com> [3.10.0-422.rt56.307.el7]
- [rt] kernel-rt-3.10.0-422.rt56.307.el7 (Clark Williams) [1280494]

* Wed Jun 08 2016 Clark Williams <williams@redhat.com> [3.10.0-422.rt56.306.el7]
- [rt] kernel-rt-3.10.0-422.rt56.306.el7 (Clark Williams) [1280494]

* Wed Jun 08 2016 Clark Williams <williams@redhat.com> [3.10.0-421.rt56.305.el7]
- [rt] kernel-rt-3.10.0-421.rt56.305.el7 (Clark Williams) [1280494]

* Wed Jun 08 2016 Clark Williams <williams@redhat.com> [3.10.0-420.rt56.304.el7]
- [rt] kernel-rt-3.10.0-420.rt56.304.el7 (Clark Williams) [1280494]

* Tue Jun 07 2016 Clark Williams <williams@redhat.com> [3.10.0-419.rt56.303.el7]
- [rt] kernel-rt-3.10.0-419.rt56.303.el7 (Clark Williams) [1280494]

* Tue Jun 07 2016 Clark Williams <williams@redhat.com> [3.10.0-418.rt56.302.el7]
- [rt] kernel-rt-3.10.0-418.rt56.302.el7 (Clark Williams) [1280494]

* Tue Jun 07 2016 Clark Williams <williams@redhat.com> [3.10.0-417.rt56.301.el7]
- [rt] kernel-rt-3.10.0-417.rt56.301.el7 (Clark Williams) [1280494]

* Tue Jun 07 2016 Clark Williams <williams@redhat.com> [3.10.0-416.rt56.300.el7]
- [rt] kernel-rt-3.10.0-416.rt56.300.el7 (Clark Williams) [1280494]
- [rt] slub: Fix merge collision between RHEL update and RT changes [1280494] (Clark Williams)
- net/core: protect users of napi_alloc_cache against reentrance (Sebastian Andrzej Siewior)
- net: Another local_irq_disable/kmalloc headache (Thomas Gleixner)
- memcontrol: Prevent scheduling while atomic in cgroup code (Mike Galbraith)

* Fri May 27 2016 Clark Williams <williams@redhat.com> [3.10.0-416.rt56.299.el7]
- [rt] kernel-rt-3.10.0-416.rt56.299.el7 (Clark Williams) [1280494]

* Thu May 26 2016 Clark Williams <williams@redhat.com> [3.10.0-415.rt56.298.el7]
- [rt] kernel-rt-3.10.0-415.rt56.298.el7 (Clark Williams) [1280494]
- [rt] param: fix references to tick_nohz_enabled (Clark Williams)

* Thu May 26 2016 Clark Williams <williams@redhat.com> [3.10.0-414.rt56.297.el7]
- [rt] kernel-rt-3.10.0-414.rt56.297.el7 (Clark Williams) [1280494]

* Wed May 25 2016 Clark Williams <williams@redhat.com> [3.10.0-413.rt56.296.el7]
- [rt] kernel-rt-3.10.0-413.rt56.296.el7 (Clark Williams) [1280494]

* Wed May 25 2016 Clark Williams <williams@redhat.com> [3.10.0-412.rt56.295.el7]
- [rt] kernel-rt-3.10.0-412.rt56.295.el7 (Clark Williams) [1280494]

* Wed May 25 2016 Clark Williams <williams@redhat.com> [3.10.0-411.rt56.294.el7]
- [rt] kernel-rt-3.10.0-411.rt56.294.el7 (Clark Williams) [1280494]

* Tue May 24 2016 Clark Williams <williams@redhat.com> [3.10.0-410.rt56.293.el7]
- [rt] kernel-rt-3.10.0-410.rt56.293.el7 (Clark Williams) [1280494]

* Tue May 24 2016 Clark Williams <williams@redhat.com> [3.10.0-409.rt56.292.el7]
- [rt] kernel-rt-3.10.0-409.rt56.292.el7 (Clark Williams) [1280494]
- [rt] updated no-build arches in specfile [1280494] (Clark Williams)

* Tue May 24 2016 Clark Williams <williams@redhat.com> [3.10.0-409.rt56.291.el7]
- [rt] kernel-rt-3.10.0-409.rt56.291.el7 (Clark Williams) [1280494]

* Sun May 22 2016 Clark Williams <williams@redhat.com> [3.10.0-408.rt56.290.el7]
- [rt] kernel-rt-3.10.0-408.rt56.290.el7 (Clark Williams) [1280494]

* Fri May 20 2016 Clark Williams <williams@redhat.com> [3.10.0-407.rt56.289.el7]
- [rt] kernel-rt-3.10.0-407.rt56.289.el7 (Clark Williams) [1280494]

* Fri May 20 2016 Clark Williams <williams@redhat.com> [3.10.0-406.rt56.288.el7]
- [rt] kernel-rt-3.10.0-406.rt56.288.el7 (Clark Williams) [1280494]

* Thu May 19 2016 Clark Williams <williams@redhat.com> [3.10.0-405.rt56.287.el7]
- [rt] kernel-rt-3.10.0-405.rt56.287.el7 (Clark Williams) [1280494]

* Wed May 18 2016 Clark Williams <williams@redhat.com> [3.10.0-404.rt56.286.el7]
- [rt] kernel-rt-3.10.0-404.rt56.286.el7 (Clark Williams) [1280494]

* Tue May 17 2016 Clark Williams <williams@redhat.com> [3.10.0-403.rt56.285.el7]
- [rt] kernel-rt-3.10.0-403.rt56.285.el7 (Clark Williams) [1280494]

* Mon May 16 2016 Clark Williams <williams@redhat.com> [3.10.0-402.rt56.284.el7]
- [rt] kernel-rt-3.10.0-402.rt56.284.el7 (Clark Williams) [1280494]

* Sat May 14 2016 Clark Williams <williams@redhat.com> [3.10.0-401.rt56.283.el7]
- [rt] kernel-rt-3.10.0-401.rt56.283.el7 (Clark Williams) [1280494]

* Fri May 13 2016 Clark Williams <williams@redhat.com> [3.10.0-400.rt56.282.el7]
- [rt] kernel-rt-3.10.0-400.rt56.282.el7 (Clark Williams) [1280494]

* Thu May 12 2016 Clark Williams <williams@redhat.com> [3.10.0-399.rt56.281.el7]
- [rt] kernel-rt-3.10.0-399.rt56.281.el7 (Clark Williams) [1280494]

* Thu May 12 2016 Clark Williams <williams@redhat.com> [3.10.0-398.rt56.280.el7]
- [rt] kernel-rt-3.10.0-398.rt56.280.el7 (Clark Williams) [1280494]

* Thu May 12 2016 Clark Williams <williams@redhat.com> [3.10.0-397.rt56.279.el7]
- [rt] kernel-rt-3.10.0-397.rt56.279.el7 (Clark Williams) [1280494]

* Wed May 11 2016 Clark Williams <williams@redhat.com> [3.10.0-396.rt56.278.el7]
- [rt] kernel-rt-3.10.0-396.rt56.278.el7 (Clark Williams) [1280494]

* Tue May 10 2016 Clark Williams <williams@redhat.com> [3.10.0-395.rt56.277.el7]
- [rt] kernel-rt-3.10.0-395.rt56.277.el7 (Clark Williams) [1280494]

* Sat May 07 2016 Clark Williams <williams@redhat.com> [3.10.0-394.rt56.276.el7]
- [rt] kernel-rt-3.10.0-394.rt56.276.el7 (Clark Williams) [1280494]

* Sat May 07 2016 Clark Williams <williams@redhat.com> [3.10.0-393.rt56.275.el7]
- [rt] kernel-rt-3.10.0-393.rt56.275.el7 (Clark Williams) [1280494]

* Fri May 06 2016 Clark Williams <williams@redhat.com> [3.10.0-392.rt56.274.el7]
- [rt] kernel-rt-3.10.0-392.rt56.274.el7 (Clark Williams) [1280494]

* Fri May 06 2016 Clark Williams <williams@redhat.com> [3.10.0-391.rt56.273.el7]
- [rt] kernel-rt-3.10.0-391.rt56.273.el7 (Clark Williams) [1280494]

* Fri May 06 2016 Clark Williams <williams@redhat.com> [3.10.0-390.rt56.272.el7]
- [rt] kernel-rt-3.10.0-390.rt56.272.el7 (Clark Williams) [1280494]

* Fri May 06 2016 Clark Williams <williams@redhat.com> [3.10.0-389.rt56.271.el7]
- [rt] kernel-rt-3.10.0-389.rt56.271.el7 (Clark Williams) [1280494]

* Fri May 06 2016 Clark Williams <williams@redhat.com> [3.10.0-388.rt56.270.el7]
- [rt] kernel-rt-3.10.0-388.rt56.270.el7 (Clark Williams) [1280494]
- busy_poll: take poll_lock when busy_polling on PREEMPT_RT (Clark Williams) [1292902]

* Thu May 05 2016 Clark Williams <williams@redhat.com> [3.10.0-387.rt56.269.el7]
- [rt] kernel-rt-3.10.0-387.rt56.269.el7 (Clark Williams) [1280494]

* Thu May 05 2016 Clark Williams <williams@redhat.com> [3.10.0-386.rt56.268.el7]
- [rt] kernel-rt-3.10.0-386.rt56.268.el7 (Clark Williams) [1280494]

* Thu May 05 2016 Clark Williams <williams@redhat.com> [3.10.0-385.rt56.267.el7]
- [rt] kernel-rt-3.10.0-385.rt56.267.el7 (Clark Williams) [1280494]
- sched: Move idle_balance() to post_schedule (Steven Rostedt) [1331562]
- sched: Enable irqs in load_balance (Steven Rostedt) [1331562]
- sched,rt: break out of load balancing if an RT task appears (Rik van Riel) [1331562]
- sched/rt: Have the schedule IPI irq_work run in hard irq context (Steven Rostedt) [1332593]
- sched/rt: Hide the push_irq_work_func() declaration (Steven Rostedt) [1332593]
- sched/rt: Use IPI to trigger RT task push migration instead of pulling (Steven Rostedt) [1332593]

* Mon May 02 2016 Clark Williams <williams@redhat.com> [3.10.0-385.rt56.266.el7]
- [rt] kernel-rt-3.10.0-385.rt56.266.el7 (Clark Williams) [1280494]

* Fri Apr 29 2016 Clark Williams <williams@redhat.com> [3.10.0-384.rt56.265.el7]
- [rt] kernel-rt-3.10.0-384.rt56.265.el7 (Clark Williams) [1280494]
- Revert "net: sysrq via icmp" (Clark Williams) [1327631]

* Thu Apr 28 2016 Clark Williams <williams@redhat.com> [3.10.0-383.rt56.264.el7]
- [rt] kernel-rt-3.10.0-383.rt56.264.el7 (Clark Williams) [1280494]

* Mon Apr 25 2016 Clark Williams <williams@redhat.com> [3.10.0-382.rt56.263.el7]
- [rt] kernel-rt-3.10.0-382.rt56.263.el7 (Clark Williams) [1280494]
- [rt] configs: turn on CFS and CGROUP configs (Clark Williams) [1329393]

* Mon Apr 25 2016 Clark Williams <williams@redhat.com> [3.10.0-382.rt56.262.el7]
- [rt] kernel-rt-3.10.0-382.rt56.262.el7 (Clark Williams) [1280494]
- [rt] turn off config SLUB_CPU_PARTIAL for realtime (Clark Williams) [1329669]
- [rt] slub: Make cpu partial slab support configurable (Joonsoo Kim)

* Thu Apr 21 2016 Clark Williams <williams@redhat.com> [3.10.0-382.rt56.261.el7]
- [rt] kernel-rt-3.10.0-382.rt56.261.el7 (Clark Williams) [1280494]

* Thu Apr 21 2016 Clark Williams <williams@redhat.com> [3.10.0-381.rt56.260.el7]
- [rt] kernel-rt-3.10.0-381.rt56.260.el7 (Clark Williams) [1280494]

* Thu Apr 21 2016 Clark Williams <williams@redhat.com> [3.10.0-380.rt56.259.el7]
- [rt] kernel-rt-3.10.0-380.rt56.259.el7 (Clark Williams) [1280494]

* Thu Apr 14 2016 Clark Williams <williams@redhat.com> [3.10.0-379.rt56.258.el7]
- [rt] kernel-rt-3.10.0-379.rt56.258.el7 (Clark Williams) [1280494]

* Wed Apr 13 2016 Clark Williams <williams@redhat.com> [3.10.0-378.rt56.257.el7]
- [rt] kernel-rt-3.10.0-378.rt56.257.el7 (Clark Williams) [1280494]

* Tue Apr 12 2016 Clark Williams <williams@redhat.com> [3.10.0-377.rt56.256.el7]
- [rt] kernel-rt-3.10.0-377.rt56.256.el7 (Clark Williams) [1280494]
- fscache: fix deadlock in page.c (mis-merge) [1326472] (Clark Williams)

* Tue Apr 12 2016 Clark Williams <williams@redhat.com> [3.10.0-377.rt56.255.el7]
- [rt] kernel-rt-3.10.0-377.rt56.255.el7 (Clark Williams) [1280494]

* Tue Apr 12 2016 Clark Williams <williams@redhat.com> [3.10.0-376.rt56.254.el7]
- [rt] kernel-rt-3.10.0-376.rt56.254.el7 (Clark Williams) [1280494]
- cputime: fix mis-merge of ede53d8149707a [1325404] (Clark Williams)

* Mon Apr 11 2016 Clark Williams <williams@redhat.com> [3.10.0-376.rt56.253.el7]
- [rt] kernel-rt-3.10.0-376.rt56.253.el7 (Clark Williams) [1280494]

* Fri Apr 08 2016 Clark Williams <williams@redhat.com> [3.10.0-375.rt56.252.el7]
- [rt] kernel-rt-3.10.0-375.rt56.252.el7 (Clark Williams) [1280494]

* Thu Apr 07 2016 Clark Williams <williams@redhat.com> [3.10.0-374.rt56.251.el7]
- [rt] kernel-rt-3.10.0-374.rt56.251.el7 (Clark Williams) [1280494]

* Wed Apr 06 2016 Clark Williams <williams@redhat.com> [3.10.0-373.rt56.250.el7]
- [rt] kernel-rt-3.10.0-373.rt56.250.el7 (Clark Williams) [1280494]
- printk: Prevent console freeze due to out-of-order deadlock [1269647] (Daniel Bristot de Oliveira)

* Wed Apr 06 2016 Clark Williams <williams@redhat.com> [3.10.0-373.rt56.249.el7]
- [rt] kernel-rt-3.10.0-373.rt56.249.el7 (Clark Williams) [1280494]

* Mon Apr 04 2016 Clark Williams <williams@redhat.com> [3.10.0-372.rt56.248.el7]
- [rt] kernel-rt-3.10.0-372.rt56.248.el7 (Clark Williams) [1280494]

* Thu Mar 31 2016 Clark Williams <williams@redhat.com> [3.10.0-371.rt56.247.el7]
- [rt] kernel-rt-3.10.0-371.rt56.247.el7 (Clark Williams) [1280494]

* Thu Mar 31 2016 Clark Williams <williams@redhat.com> [3.10.0-370.rt56.246.el7]
- [rt] kernel-rt-3.10.0-370.rt56.246.el7 (Clark Williams) [1280494]

* Mon Mar 28 2016 Clark Williams <williams@redhat.com> [3.10.0-369.rt56.245.el7]
- [rt] kernel-rt-3.10.0-369.rt56.245.el7 (Clark Williams) [1280494]

* Thu Mar 24 2016 Clark Williams <williams@redhat.com> [3.10.0-367.rt56.244.el7]
- [rt] kernel-rt-3.10.0-367.rt56.244.el7 (Clark Williams) [1280494]

* Mon Mar 21 2016 Clark Williams <williams@redhat.com> [3.10.0-366.rt56.243.el7]
- [rt] kernel-rt-3.10.0-366.rt56.243.el7 (Clark Williams) [1280494]

* Mon Mar 14 2016 Clark Williams <williams@redhat.com> [3.10.0-365.rt56.242.el7]
- [rt] kernel-rt-3.10.0-365.rt56.242.el7 (Clark Williams) [1280494]

* Fri Mar 11 2016 Clark Williams <williams@redhat.com> [3.10.0-364.rt56.241.el7]
- [rt] kernel-rt-3.10.0-364.rt56.241.el7 (Clark Williams) [1280494]

* Thu Mar 10 2016 Clark Williams <williams@redhat.com> [3.10.0-363.rt56.240.el7]
- [rt] kernel-rt-3.10.0-363.rt56.240.el7 (Clark Williams) [1280494]

* Wed Mar 09 2016 Clark Williams <williams@redhat.com> [3.10.0-362.rt56.239.el7]
- [rt] kernel-rt-3.10.0-362.rt56.239.el7 (Clark Williams) [1280494]

* Tue Mar 08 2016 Clark Williams <williams@redhat.com> [3.10.0-360.rt56.238.el7]
- [rt] kernel-rt-3.10.0-360.rt56.238.el7 (Clark Williams) [1280494]

* Mon Mar 07 2016 Clark Williams <williams@redhat.com> [3.10.0-359.rt56.237.el7]
- [rt] kernel-rt-3.10.0-359.rt56.237.el7 (Clark Williams) [1280494]

* Fri Mar 04 2016 Clark Williams <williams@redhat.com> [3.10.0-357.rt56.236.el7]
- [rt] kernel-rt-3.10.0-357.rt56.236.el7 (Clark Williams) [1280494]

* Wed Mar 02 2016 Clark Williams <williams@redhat.com> [3.10.0-356.rt56.235.el7]
- [rt] kernel-rt-3.10.0-356.rt56.235.el7 (Clark Williams) [1280494]

* Tue Mar 01 2016 Clark Williams <williams@redhat.com> [3.10.0-355.rt56.234.el7]
- [rt] kernel-rt-3.10.0-355.rt56.234.el7 (Clark Williams) [1280494]

* Mon Feb 29 2016 Clark Williams <williams@redhat.com> [3.10.0-353.rt56.233.el7]
- [rt] kernel-rt-3.10.0-353.rt56.233.el7 (Clark Williams) [1280494]

* Thu Feb 25 2016 Clark Williams <williams@redhat.com> [3.10.0-351.rt56.232.el7]
- [rt] kernel-rt-3.10.0-351.rt56.232.el7 (Clark Williams) [1280494]
- Revert "[TEMP] sched/clock, x86: Use mul_u64_u32_shr() for native_sched_clock()" (Clark Williams)
- Revert "[TEMP] sched/clock, x86: Move some cyc2ns() code around" (Clark Williams)
- Revert "[TEMP] sched/clock, x86: Rewrite cyc2ns() to avoid the need to disable IRQs" (Clark Williams)

* Wed Feb 17 2016 Clark Williams <williams@redhat.com> [3.10.0-350.rt56.231.el7]
- [rt] kernel-rt-3.10.0-350.rt56.231.el7 (Clark Williams) [1280494]

* Mon Feb 15 2016 Clark Williams <williams@redhat.com> [3.10.0-349.rt56.230.el7]
- [rt] kernel-rt-3.10.0-349.rt56.230.el7 (Clark Williams) [1280494]

* Wed Feb 10 2016 Clark Williams <williams@redhat.com> [3.10.0-348.rt56.229.el7]
- [rt] kernel-rt-3.10.0-348.rt56.229.el7 (Clark Williams) [1280494]

* Mon Feb 08 2016 Clark Williams <williams@redhat.com> [3.10.0-347.rt56.228.el7]
- [rt] kernel-rt-3.10.0-347.rt56.228.el7 (Clark Williams) [1280494]
- perf/x86: Fix time_shift in perf_event_mmap_page (Prarit Bhargava) [http://bugzilla.redhat.com/1303663]
- perf/x86: Improve accuracy of perf/sched clock (Prarit Bhargava) [http://bugzilla.redhat.com/1303663]
- x86: Use preempt_disable_notrace() in cycles_2_ns() (Prarit Bhargava) [http://bugzilla.redhat.com/1303663]
- sched/x86/tsc: Initialize multiplier to 0 (Prarit Bhargava) [http://bugzilla.redhat.com/1303663]

* Thu Feb 04 2016 Clark Williams <williams@redhat.com> [3.10.0-346.rt56.227.el7]
- [rt] kernel-rt-3.10.0-346.rt56.227.el7 (Clark Williams) [1280494]
- fix merge issue in blk_mq_run_hw_queue (Daniel Bristot de Oliveira)
- block: blk-mq: Use swait (Daniel Bristot de Oliveira)

* Wed Feb 03 2016 Clark Williams <williams@redhat.com> [3.10.0-346.rt56.226.el7]
- [rt] kernel-rt-3.10.0-346.rt56.226.el7 (Clark Williams) [1280494]

* Wed Feb 03 2016 Clark Williams <williams@redhat.com> [3.10.0-344.rt56.225.el7]
- [rt] kernel-rt-3.10.0-344.rt56.225.el7 (Clark Williams) [1280494]
- fcoe: fix mismatch of get_cpu and put_cpu_light. (Steven Rostedt)
-     [rt] irqwork: Move irq safe work to irq context (Thomas Gleixner)
-     [rt] net: provide a way to delegate processing a softirq to ksoftirqd (Sebastian Andrzej Siewior)
-     [rt] net: move xmit_recursion to per-task variable on -RT (Sebastian Andrzej Siewior)
-     [rt] softirq: split timer softirqs out of ksoftirqd (Sebastian Andrzej Siewior)
-     [rt] rtmutex: Handle non enqueued waiters gracefully (Thomas Gleixner)
- [TEMP] sched/clock, x86: Rewrite cyc2ns() to avoid the need to disable IRQs (Prarit Bhargava)
- [TEMP] sched/clock, x86: Move some cyc2ns() code around (Prarit Bhargava)
- [TEMP] sched/clock, x86: Use mul_u64_u32_shr() for native_sched_clock() (Prarit Bhargava)
- Revert "timers: TEMPORARY: fix calling smp_processor_id from __cycles_2_ns()" (Clark Williams)

* Mon Feb 01 2016 Clark Williams <williams@redhat.com> [3.10.0-344.rt56.224.el7]
- [rt] kernel-rt-3.10.0-344.rt56.224.el7 (Clark Williams) [1280494]

* Mon Feb 01 2016 Clark Williams <williams@redhat.com> [3.10.0-342.rt56.223.el7]
- [rt] kernel-rt-3.10.0-342.rt56.223.el7 (Clark Williams) [1280494]
- timers: TEMPORARY: fix calling smp_processor_id from __cycles_2_ns() (Clark Williams)
- Revert "softirq: Add global local lock to keep softirqs out of local_bh_disable sections" (Clark Williams)
- netpoll: reorder if condition to account for null 'dev' (Clark Williams)
- stop_machine: force initialization of stop_cpus_lock (Clark Williams)
- specfile: kernel-rt-3.10.0-342.rt56.222.el7 (Clark Williams)
- [rt] kernel-rt-3.10.0-342.rt56.222.el7 (Clark Williams) [1280494]
- stop_machine: bring stop_machine() up to upstream 4.4 behavior (Clark Williams)
- Revert "sched: Introduce temporary FAIR_GROUP_SCHED dependency for load-tracking" (Alex Shi)

* Wed Jan 27 2016 Clark Williams <williams@redhat.com> [3.10.0-342.rt56.222.el7]
- [rt] kernel-rt-3.10.0-342.rt56.222.el7 (Clark Williams) [1280494]
- stop_machine: bring stop_machine() up to upstream 4.4 behavior (Clark Williams)
- Revert "sched: Introduce temporary FAIR_GROUP_SCHED dependency for load-tracking" (Alex Shi)

* Fri Jan 15 2016 Clark Williams <williams@redhat.com> [3.10.0-340.rt56.221.el7]
- [rt] kernel-rt-3.10.0-340.rt56.221.el7 (Clark Williams) [1280494]
- rcu: make the -rt kernel boot again [1298350] (Luiz Capitulino)

* Wed Jan 13 2016 Clark Williams <williams@redhat.com> [3.10.0-340.rt56.220.el7]
- [rt] kernel-rt-3.10.0-340.rt56.220.el7 (Clark Williams) [1280494]

* Tue Jan 12 2016 Clark Williams <williams@redhat.com> [3.10.0-339.rt56.219.el7]
- [rt] kernel-rt-3.10.0-339.rt56.219.el7 (Clark Williams) [1280494]

* Mon Jan 11 2016 Clark Williams <williams@redhat.com> [3.10.0-338.rt56.218.el7]
- [rt] kernel-rt-3.10.0-338.rt56.218.el7 (Clark Williams) [1280494]

* Fri Jan 08 2016 Clark Williams <williams@redhat.com> [3.10.0-337.rt56.217.el7]
- [rt] kernel-rt-3.10.0-337.rt56.217.el7 (Clark Williams) [1280494]

* Thu Jan 07 2016 Clark Williams <williams@redhat.com> [3.10.0-336.rt56.216.el7]
- [rt] kernel-rt-3.10.0-336.rt56.216.el7 (Clark Williams) [1280494]

* Wed Jan 06 2016 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-335.rt56.215.el7]
- softirq: Perform softirqs in local_bh_enable() for a limited amount of time [1292927]
- rcu: Boost rcuc if it has 4 jiffies before splatting [1292927]

* Tue Dec 22 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-335.rt56.214.el7]
- Revert "ixgbe: Prevent livelock spinning grabbing ixgbe_qv_lock" [1292902]

* Fri Dec 18 2015 Clark Williams <williams@redhat.com> [3.10.0-335.rt56.213.el7]
- [rt] kernel-rt-3.10.0-335.rt56.213.el7 (Clark Williams) [1280494]
- Revert "ixgbevf: Prevent livelock spinning grabbing ixgbevf_qv_lock" (Clark Williams) [1292902]
- rcu: Boost rcuc if it has 2 jiffies before splatting (Steven Rostedt) [1292927]
- netpoll: Always take poll_lock when doing polling (Steven Rostedt) [1292902]

* Wed Dec 16 2015 Clark Williams <williams@redhat.com> [3.10.0-335.rt56.212.el7]
- [rt] kernel-rt-3.10.0-335.rt56.212.el7 (Clark Williams) [1280494]

* Tue Dec 01 2015 Clark Williams <williams@redhat.com> [3.10.0-334.rt56.211.el7]
- [rt] kernel-rt-3.10.0-334.rt56.211.el7 (Clark Williams) [1280494]

* Mon Nov 23 2015 Clark Williams <williams@redhat.com> [3.10.0-333.rt56.210.el7]
- [rt] kernel-rt-3.10.0-333.rt56.210.el7 (Clark Williams) [1280494]

* Mon Nov 23 2015 Clark Williams <williams@redhat.com> [3.10.0-333.rt56.209.el7]
- [rt] kernel-rt-3.10.0-333.rt56.209.el7 (Clark Williams) [1280494]

* Fri Nov 20 2015 Clark Williams <williams@redhat.com> [3.10.0-332.rt56.208.el7]
- [rt] kernel-rt-3.10.0-332.rt56.208.el7 (Clark Williams) [1280494]

* Fri Nov 13 2015 Clark Williams <williams@redhat.com> [3.10.0-330.rt56.207.el7]
- [rt] kernel-rt-3.10.0-330.rt56.207.el7 (Clark Williams) [1280494]

* Thu Nov 12 2015 Clark Williams <williams@redhat.com> [3.10.0-329.rt56.206.el7]
- [rt] kernel-rt-3.10.0-329.rt56.206.el7 (Clark Williams) [1280494]
- softirq: Add global local lock to keep softirqs out of local_bh_disable sections (Steven Rostedt)

* Thu Nov 12 2015 Clark Williams <williams@redhat.com> [3.10.0-329.rt56.205.el7]
- [rt] kernel-rt-3.10.0-329.rt56.205.el7 (Clark Williams) [1280494]

* Thu Oct 29 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-327.rt56.204.el7]
- [rt] merged kernel-3.10.0-327.el7 [1201915]
- [rt] nohz: enable nohz if nohz_full encountered on boot command line [1276071]

* Fri Oct 23 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-326.rt56.203.el7]
- [rt] merged kernel-3.10.0-326.el7 [1201915]

* Mon Oct 19 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-325.rt56.202.el7]
- [rt] merged kernel-3.10.0-325.el7 [1201915]

* Wed Oct 14 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-324.rt56.201.el7]
- [rt] merged kernel-3.10.0-324.el7 [1201915]

* Mon Oct 12 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-323.rt56.200.el7]
- [rt] merged kernel-3.10.0-323.el7 [1201915]

* Tue Oct 06 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-322.rt56.199.el7]
- [rt] merged kernel-3.10.0-322.el7 [1201915]

* Thu Oct 01 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-321.rt56.198.el7]
- [rt] perf: set the perf hrtimer handler to irqsafe [1196232]

* Wed Sep 30 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-321.rt56.197.el7]
- [rt] merged kernel-3.10.0-321.el7 [1201915]

* Tue Sep 29 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-320.rt56.196.el7]
- [rt] nohz: disabled by default [1206356]

* Mon Sep 28 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-320.rt56.195.el7]
- [rt] merged kernel-3.10.0-320.el7 [1201915]
- [rt] ixgbevf: Prevent livelock spinning grabbing ixgbevf_qv_lock [1265882]

* Tue Sep 22 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-319.rt56.194.el7]
- [rt] merged kernel-3.10.0-319.el7 (Luis Goncalves) [1201915]

* Tue Sep 22 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-318.rt56.193.el7]
- [rt] merged kernel-3.10.0-318.el7 (Luis Goncalves) [1201915]
- [rt] sunrpc: use get_cpu_light() for getting the CPU value (Steven Rostedt) [1265264]

* Sun Sep 20 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-317.rt56.192.el7]
- [rt] merged kernel-3.10.0-317.el7 (Luis Goncalves) [1201915]

* Fri Sep 18 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-316.rt56.191.el7]
- [rt] revert "[netdrv] ixgbe: Refactor busy poll socket code to address multiple issues" [1261109]

* Tue Sep 15 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-316.rt56.190.el7]
- [rt] merged kernel-3.10.0-316.el7 (Luis Goncalves) [1201915]

* Tue Sep  8 2015 Clark Williams <williams@redhat.com> [3.10.0-315.rt56.189.el7]
- [rt] merged kernel-3.10.0-315.el7 (Clark Williams) [1201915]

* Fri Sep  4 2015 Clark Williams <williams@redhat.com> [3.10.0-314.rt56.188.el7]
- [rt] merged kernel-3.10.0-314.el7 (Clark Williams) [1201915]

* Fri Sep  4 2015 Clark Williams <williams@redhat.com> [3.10.0-313.rt56.187.el7]
- x86: Convert mce timer to hrtimer [1257341]

* Tue Sep  1 2015 Clark Williams <williams@redhat.com> [3.10.0-313.rt56.186.el7]
- [rt] merged kernel-3.10.0-313.el7 (Clark Williams) [1201915]

* Mon Aug 31 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-312.rt56.185.el7]
- [rt] merged kernel-3.10.0-312.el7 (Luis Goncalves) [1201915]

* Fri Aug 28 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-311.rt56.184.el7]
- [rt] merged kernel-3.10.0-311.el7 (Luis Goncalves) [1201915]

* Thu Aug 27 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-310.rt56.183.el7]
- [rt] merged kernel-3.10.0-310.el7 (Luis Goncalves) [1201915]

* Mon Aug 24 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-309.rt56.182.el7]
- [rt] merged kernel-3.10.0-309.el7 (Luis Goncalves) [1201915]

* Mon Aug 24 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-308.rt56.181.el7]
- [rhel-rt] specfile: run depmod when installing -kvm sub-packages [1255341] [1245306]

* Mon Aug 24 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-308.rt56.180.el7]
- [rt] merged kernel-3.10.0-308.el7 (Luis Goncalves) [1201915]

* Wed Aug 19 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-306.0.1.rt56.179.el7]
- [misc] redhat: roll back to pre-release secureboot keys [1254992] [1201915]

* Mon Aug 17 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-306.rt56.179.el7]
- [rt] merged kernel-3.10.0-306.el7 (Luis Goncalves) [1201915]

* Mon Aug 17 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-305.rt56.178.el7]
- [rt] merged kernel-3.10.0-305.el7 (Luis Goncalves) [1201915]

* Thu Aug 13 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-304.rt56.177.el7]
- [rhel-rt] specfile: create -kvm-debuginfo sub-packages for kernel [1245306]

* Mon Aug 10 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-304.rt56.176.el7]
- [rt] merged kernel-3.10.0-304.el7 (Luis Goncalves) [1201915]
- [rt] hwlat_detector: record max diff from outer sample (Clark Williams) [1251570]

* Thu Aug 06 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-303.rt56.175.el7]
- [rt] merged kernel-3.10.0-303.el7 (Luis Goncalves) [1201915]

* Sat Aug 01 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-302.rt56.174.el7]
- [rt] merged kernel-3.10.0-302.el7 (Luis Goncalves) [1201915]
- [rhel-rt] specfile: add logic to create -kvm sub-packages for kernel (Clark Williams) [1245306]

* Thu Jul 30 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-301.rt56.173.el7]
- [rt] merged kernel-3.10.0-301.el7 (Luis Goncalves) [1201915]

* Mon Jul 27 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-300.rt56.172.el7]
- [rt] merged kernel-3.10.0-300.el7 (Luis Goncalves) [1201915]

* Thu Jul 23 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-298.rt56.171.el7]
- [rt] merged kernel-3.10.0-298.el7 (Luis Goncalves) [1201915]

* Wed Jul 22 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-297.rt56.170.el7]
- [rt] skbuff: Use local_lock instead of disabling interrupts (Steven Rostedt) [1245026]

* Tue Jul 21 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-297.rt56.169.el7]
- [rt] merged kernel-3.10.0-297.el7 (Luis Goncalves) [1201915]

* Sun Jul 19 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-296.rt56.168.el7]
- [rt] merged kernel-3.10.0-296.el7 (Luis Goncalves) [1201915]
- [rt] reverted hrtimer changes introduced in -294 (Luis Goncalves) [1201915]

* Tue Jul 14 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-294.rt56.167.el7]
- [rt] merged kernel-3.10.0-294.el7 (Luis Goncalves) [1201915]

* Tue Jul 07 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-292.rt56.166.el7]
- [rt] merged kernel-3.10.0-292.el7 (Luis Goncalves) [1201915]

* Tue Jul 07 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-291.rt56.165.el7]
- [rt] merged kernel-3.10.0-291.el7 (Luis Goncalves) [1201915]

* Tue Jul 07 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-290.rt56.164.el7]
- [rhel-rt] fold -virt configs into the production kernel [1201915]

* Mon Jul 06 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-290.rt56.163.el7]
- [rt] merged kernel-3.10.0-290.el7 (Luis Goncalves) [1201915]
- backport irq_work changes from 3.18-rt [1240403]

* Mon Jun 29 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-287.rt56.162.el7]
- [rt] merged kernel-3.10.0-287.el7 (Luis Goncalves) [1201915]

* Fri Jun 26 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-283.rt56.161.el7]
- [rt] merged kernel-3.10.0-283.el7 (Luis Goncalves) [1201915]

* Wed Jun 24 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-280.rt56.160.el7]
- [rt] merged kernel-3.10.0-280.el7 (Luis Goncalves) [1201915]

* Tue Jun 23 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-277.rt56.159.el7]
- [rt] nfs: Use __write_seqcount_begin() version (Steven Rostedt) [1230365]
- scripts: avoid debuginfo hash collisions on scripts/ [1209952]

* Tue Jun 23 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-277.rt56.158.el7]
- [rt] merged kernel-3.10.0-277.el7 (Luis Goncalves) [1201915]

* Thu Jun 18 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-269.rt56.157.el7]
- [rt] merged kernel-3.10.0-269.el7 (Luis Goncalves) [1201915]

* Wed Jun 17 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-268.rt56.156.el7]
- [rt] merged kernel-3.10.0-268.el7 (Luis Goncalves) [1201915]

* Wed Jun 17 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-267.rt56.155.el7]
- [rt] merged kernel-3.10.0-267.el7 (Luis Goncalves) [1201915]

* Mon Jun 15 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-264.rt56.154.el7]
- [rt] merged kernel-3.10.0-264.el7 (Luis Goncalves) [1201915]

* Thu Jun 11 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-262.rt56.153.el7]
- [rt] fix small regressions introduced during the merge (Luis Goncalves) [1201915]

* Tue Jun 09 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-262.rt56.152.el7]
- [rt] merged kernel-3.10.0-262.el7 (Luis Goncalves) [1201915]

* Mon Jun 08 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-258.rt56.151.el7]
- [rt] merged kernel-3.10.0-258.el7 (Luis Goncalves) [1201915]

* Thu May 21 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-237.rt56.150.el7]
- [rt] specfile: avoid using obsolete rootfs paths [1211667]
- scripts: avoid debuginfo hash collisions on scripts/ [1209952]
- xfs: Disable percpu SB on PREEMPT_RT_FULL (Steven Rostedt) [1223089]

* Thu Apr 23 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-237.rt56.149.el7]
- [rt] configs: add the required changes to the -virt kernel [1213866]

* Fri Apr 17 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-237.rt56.148.el7]
- hrtimer: make hrtimer_start() (almost) never fail (Luiz Capitulino) [1207691]
- ixgbe: Prevent livelock spinning grabbing ixgbe_qv_lock (Steven Rostedt) [1209610]

* Sun Apr 12 2015 Luis Claudio R. Goncalves <lgoncalv@redhat.com> [3.10.0-237.rt56.147.el7]
- [rt] rebase to kernel -237 build (Luis Goncalves) [1201915]

* Tue Mar 24 2015 Clark Williams <williams@redhat.com> [3.10.0-234.rt56.146.el7]
- [rt]: kernel-rt-3.10.0-233.rt56.144.el7 (Clark Williams) [1201915]

* Mon Mar 23 2015 Clark Williams <williams@redhat.com> [3.10.0-233.rt56.145.el7]
- [rt]: kernel-rt-3.10.0-233.rt56.144.el7 (Clark Williams) [1201915]

* Tue Mar 17 2015 Clark Williams <williams@redhat.com> [3.10.0-232.rt56.144.el7]
- [rt] rebase to kernel -232 build (Clark Williams) [1200897]

* Fri Mar 13 2015 Clark Williams <williams@redhat.com> [3.10.0-231.rt56.143.el7]
- [rt] rebase to kernel -231 build and update build infrastructure (Clark Williams) [1200897]
- sunrpc: don't wait for write before allowing reads from use-gss-proxy file (Jeff Layton)

* Tue Mar 03 2015 Clark Williams <williams@redhat.com> [3.10.0-229.rt56.142]
- netfilter: fix up incorrect type passed to xt_register_match (Clark Williams)
- Revert "netfilter: xt_connlimit: remove revision 0" (John Kacur) [1169755]

* Wed Feb 11 2015 Clark Williams <williams@redhat.com>  [3.10.0-229.rt56.141]
- [rt] mce: fixed RHEL-RT mis-merge with mce cleanup commit [1191668]

* Thu Jan 29 2015 Clark Williams <williams@redhat.com>  [3.10.0-229.rt56.140]
- rebased to rhel build 229 [1160430]

* Tue Jan 27 2015 Clark Williams <williams@redhat.com>  [3.10.0-227.rt56.139]
- rebased to rhel build 227 [1160430]

* Mon Jan 26 2015 Clark Williams <williams@redhat.com>  [3.10.0-226.rt56.138]
- rebased to rhel build 226 [1160430]

* Fri Jan 23 2015 Clark Williams <williams@redhat.com>  [3.10.0-225.rt56.137]
- rebased to rhel build 225 [1160430]

* Mon Jan 19 2015 Clark Williams <williams@redhat.com>  [3.10.0-224.rt56.136]
- rebased to rhel build 224 [1160430]

* Tue Jan 13 2015 Clark Williams <williams@redhat.com>  [3.10.0-223.rt56.135]
- rebased to rhel build 223 [1160430]

* Mon Jan 12 2015 Clark Williams <williams@redhat.com>  [3.10.0-222.rt56.134]
- rebased to rhel build 222 [1160430]
- net: iwlwifi: driver fails to initialize on RHEL-RT 3.10.0-220.rt56.el7 [1178919]

* Thu Jan  8 2015 Clark Williams <williams@redhat.com>  [3.10.0-221.rt56.133]
-  Setting up the function tracer hardlocks the machine [1172823]

* Wed Jan  7 2015 Clark Williams <williams@redhat.com>  [3.10.0-221.rt56.132]
- rebased to rhel build 221 [1160430]
- Performance problems with 3.10 LAZY_PREEMPT on Realtime kernel [1179371]

* Mon Jan  5 2015 Clark Williams <williams@redhat.com>  [3.10.0-220.rt56.131]
- net: iwlwifi: request only a threaded handler for interrupts [1178919]

* Tue Dec 23 2014 Clark Williams <williams@redhat.com>  [3.10.0-220.rt56.130]
- rebased to rhel build 220 [1160430]

* Thu Dec 18 2014 Clark Williams <williams@redhat.com>  [3.10.0-219.rt56.129]
- rebased to rhel build 219 [1160430]

* Thu Dec 18 2014 Clark Williams <williams@redhat.com>  [3.10.0-218.rt56.128]
- rebased to rhel build 218 [1160430]

* Mon Dec 15 2014 Clark Williams <williams@redhat.com>  [3.10.0-217.rt56.127]
- rebased to rhel build 217 [1160430]

* Tue Dec  9 2014 Clark Williams <williams@redhat.com>  [3.10.0-216.rt56.126]
- rebased to rhel build 216 [1160430]
- mm: Remove open coded local_irq_{enable,disable}() [1167452]

* Fri Dec  5 2014 Clark Williams <williams@redhat.com>  [3.10.0-213.rt56.125]
- rebased to rhel build 213 [1160430]

* Wed Dec  3 2014 Clark Williams <williams@redhat.com>  [3.10.0-212.rt56.124]
- rebased to rhel build 212 [1160430]

* Tue Dec  2 2014 Clark Williams <williams@redhat.com>  [3.10.0-211.rt56.123]
- rebased to rhel build 211 [1160430]

* Mon Nov 24 2014 Clark Williams <williams@redhat.com>  [3.10.0-210.rt56.122]
- rebased to rhel build 210 [1160430]

* Mon Nov 24 2014 Clark Williams <williams@redhat.com>  [3.10.0-209.rt56.121]
- rebased to rhel build 209 [1160430]

* Mon Nov 24 2014 Clark Williams <williams@redhat.com>  [3.10.0-206.rt56.120]
- rebased to rhel build 206 [1160430]

* Thu Nov 20 2014 Clark Williams <williams@redhat.com>  [3.10.0-205.rt56.119]
- rebased to rhel build 205 [1160430]

* Wed Nov 19 2014 Clark Williams <williams@redhat.com>  [3.10.0-204.rt56.118]
- ftrace/x86: Add frames pointers to trampoline as necessary [1161760]

* Tue Nov 18 2014 Clark Williams <williams@redhat.com>  [3.10.0-204.rt56.117]
- Fix scheduling while atomic in ring buffer for PREEMPT_RT [1161760]

* Mon Nov 17 2014 Clark Williams <williams@redhat.com>  [3.10.0-204.rt56.116]
- rebased to rhel build 204 [1160430]

* Fri Nov 14 2014 Clark Williams <williams@redhat.com>  [3.10.0-203.rt56.115]
- rebased to rhel build 203 [1160430]

* Tue Nov 11 2014 Clark Williams <williams@redhat.com>  [3.10.0-201.rt56.114]
- rebased to rhel build 201 [1160430]

* Mon Nov 10 2014 Clark Williams <williams@redhat.com> - 3.10.0-200.rt56.113
- rebased to rhel build 200 [1160430]
- apply blk_mq patches to avoid "scheduling while atomic" [1162253]

* Wed Nov  5 2014 Clark Williams <williams@redhat.com> - 3.10.0-198.rt56.112
- rebased to rhel build 198 [1160430]
- kernel: zero the cpumask before running sched_getaffinity [1158225]

* Tue Nov  4 2014 Clark Williams <williams@redhat.com> - 3.10.0-196.rt56.111
- corrected build and commit syntax for dist-git [1151560]

* Tue Oct 28 2014 Clark Williams <williams@redhat.com> - 3.10.0-196.rt56.110
- initial rhel-7.1 build [1151560]
- rebased to rhel build 196 [1159388]

* Tue Oct 28 2014 Clark Williams <williams@redhat.com> - 3.10.0-193.rt56.109
- virt: reverted blk-mq commits in virtio-blk due to 'scheduling while atomic' errors

* Fri Oct 24 2014 Clark Williams <williams@redhat.com> - 3.10.0-193.rt56.108
- configs: turned on CONFIG_VIRT_DRIVERS for virt config on RHEL7
- configs: turned on CONFIG_VIRTIO_MMIO for virt config on RHEL7
- configs: turned on CONFIG_VIRTIO_MMIO_CMDLINE_DEVICES for virt configs on RHEL7
- configs: turned on CONFIG_PARAVIRT_DEBUG for virt config on RHEL7
- configs: turned on CONFIG_PARAVIRT_TIME_ACCOUNTING for virt config on RHEL7
- configs: turned on CONFIG_DEBUG_VIRTUAL for virt config on RHEL7

* Fri Oct 24 2014 Clark Williams <williams@redhat.com> - 3.10.0-193.rt56.107
- rebased to rhel build 193

* Wed Oct 22 2014 Clark Williams <williams@redhat.com> - 3.10.0-191.rt56.106
- rebased to rhel build 191

* Wed Oct 22 2014 Clark Williams <williams@redhat.com> - 3.10.0-190.rt56.105
- cpumask: set nr_cpumask_bits to nr_cpu_ids on PREEMPT_RT

* Tue Oct 21 2014 Clark Williams <williams@redhat.com> - 3.10.0-190.rt56.104
- rebased to rhel build 190

* Thu Oct 16 2014 Clark Williams <williams@redhat.com> - 3.10.0-188.rt56.103
- configs: turned off CONFIG_MIGRATION and CONFIG_CMA due to latency spikes

* Tue Oct 14 2014 Clark Williams <williams@redhat.com> - 3.10.0-188.rt56.102
- turned on -virt sub-package build for el7rt

* Mon Oct 13 2014 Clark Williams <williams@redhat.com> - 3.10.0-188.rt56.101
- rebased to rhel build 188

* Fri Oct 10 2014 Clark Williams <williams@redhat.com> - 3.10.0-186.rt56.100
- turned off default build of -virt and -vanilla kernel packages
- rebased to rhel build 186

* Thu Oct  9 2014 Clark Williams <williams@redhat.com> - 3.10.0-185.rt56.99
- configs: modified virt configs to match RHEL7 configs
- configs: turned on CONFIG_FAIR_GROUP_SCHED and CFS_BANDWIDTH
- rebased to rhel build 185

* Wed Oct  8 2014 Clark Williams <williams@redhat.com> - 3.10.0-183.rt56.98
- rebased to rhel build 183

* Tue Oct  7 2014 Clark Williams <williams@redhat.com> - 3.10.0-182.rt56.97
- configs: Turned on CONFIG_MIGRATION and CONFIG_CMA (left COMPACTION off)
- x86: updated arch/x86/boot/tools/build.c to use unified types.h
- rebased to rhel build 182

* Mon Oct  6 2014 Clark Williams <williams@redhat.com> - 3.10.0-179.rt56.96
- configs: turn off CONFIG_PARAVIRT_SPINLOCKS for virt config
- configs: turn off CONFIG_PARAVIRT_TIME_ACCOUNTING for virt config

* Sun Oct  5 2014 Clark Williams <williams@redhat.com> - 3.10.0-179.rt56.95
- specfile: fixed bogus path for new-kernel-pkg
- specfile: removed incorrect linux-firmware version

* Sun Oct  5 2014 Clark Williams <williams@redhat.com> - 3.10.0-179.rt56.94
- mm: move clear_hwpoisoned_pages under CONFIG_MEMORY_HOTREMOVE
- configs: handle unknown configs for el6rt

* Sun Oct  5 2014 Clark Williams <williams@redhat.com> - 3.10.0-179.rt56.93
- specfile: require new linux-firmware version (match RHEL)
- configs: Turned off CONFIG_MIGRATION and related configs
- rebased to rhel build 179

* Fri Oct  3 2014 Clark Williams <williams@redhat.com> - 3.10.0-178.rt56.92
- tracing: Disable tracing on warning
- rebased to rhel build 178

* Fri Oct  3 2014 Clark Williams <williams@redhat.com> - 3.10.0-177.rt56.91
- rebased to rhel build 177

* Tue Sep 30 2014 Clark Williams <williams@redhat.com> - 3.10.0-176.rt56.90
- rebased to rhel build 176

* Tue Sep 30 2014 Clark Williams <williams@redhat.com> - 3.10.0-174.rt56.89
- rebased to rhel build 174

* Mon Sep 29 2014 Clark Williams <williams@redhat.com> - 3.10.0-171.rt56.88
- rebased to rhel build 171

* Wed Sep 24 2014 Clark Williams <williams@redhat.com> - 3.10.0-170.rt56.87
- rebased to rhel build 170

* Tue Sep 23 2014 Clark Williams <williams@redhat.com> - 3.10.0-168.rt56.86
- rebased to rhel build 168

* Tue Sep 23 2014 Clark Williams <williams@redhat.com> - 3.10.0-167.rt56.85
- rebased to rhel build 167

* Fri Sep 19 2014 Clark Williams <williams@redhat.com> - 3.10.0-163.rt56.84
- rebased to rhel build 163

* Tue Sep 16 2014 Clark Williams <williams@redhat.com> - 3.10.0-161.rt56.83
- rebased to rhel build 161

* Tue Sep 16 2014 Clark Williams <williams@redhat.com> - 3.10.0-160.rt56.82
- rebased to rhel build 160

* Mon Sep 15 2014 Clark Williams <williams@redhat.com> - 3.10.0-158.rt56.81
- rebased to rhel build 158

* Mon Sep 15 2014 Clark Williams <williams@redhat.com> - 3.10.0-155.rt56.80
- rcu: unify boost and kthread priorities then make it boot time settable
- configs: added RCU_KTHREAD_PRIO and removed RCU_BOOST_PRIO

* Fri Sep 12 2014 Clark Williams <williams@redhat.com> - 3.10.0-155.rt56.79
- rebased to rhel build 155
- removed CONFIG_RCU_NOCB_CPU_* overrides in rt tree to use RHEL values
- changed CONFIG_RCU_BOOST_PRIO to 2 for realtime

* Thu Sep 11 2014 Clark Williams <williams@redhat.com> - 3.10.0-154.rt56.78
- rebased to rhel build 154

* Thu Sep  4 2014 Clark Williams <williams@redhat.com> - 3.10.0-152.rt56.77
- rebased to rhel build 152

* Tue Sep  2 2014 Clark Williams <williams@redhat.com> - 3.10.0-150.rt56.76
- rebased to rhel build 150

* Tue Sep  2 2014 Clark Williams <williams@redhat.com> - 3.10.0-147.rt56.75
- rebased to rhel build 147

* Wed Aug 27 2014 Clark Williams <williams@redhat.com> - 3.10.0-144.rt56.74
- brought RT patch up to current 3.10 level (-rt56)
  - Fix latency histogram after "hrtimer: Set expiry time before switch_hrtimer_base()"
  - timer: do not spin_trylock() on UP
  - rcu: make RCU_BOOST default on RT
  - net: gianfar: do not disable interrupts
  - net: gianfar: do not try to cleanup TX packets if they are not done

* Wed Aug 13 2014 Clark Williams <williams@redhat.com> - 3.10.0-144.rt34.73
- rebased to rhel build 144

* Thu Aug  7 2014 Clark Williams <williams@redhat.com> - 3.10.0-143.rt34.72
- rebased to rhel build 143

* Tue Aug  5 2014 Clark Williams <williams@redhat.com> - 3.10.0-142.rt34.71
- add the .virt variant modules to the signing pass loop
- turn off lockdep in main rt kernel
- x86: MCE: Add raw_lock conversion again

* Mon Aug  4 2014 Clark Williams <williams@redhat.com> - 3.10.0-142.rt34.70
- rebased to rhel build 142

* Thu Jul 31 2014 Clark Williams <williams@redhat.com> - 3.10.0-140.rt34.69
- fix cpu hotplug commit error

* Tue Jul 29 2014 Clark Williams <williams@redhat.com> - 3.10.0-140.rt34.68
- rebased to rhel build 140

* Fri Jul 25 2014 Clark Williams <williams@redhat.com> - 3.10.0-138.rt34.67
- debugging: turn on lockdep in main rt kernel for beaker tests
- from Luis Claudio R. Goncalves <lgoncalv@redhat.com>:
  - redhat: remove leftover from old specfile
  - redhat: fixed version and changelog on the specfile
  - redhat: fix the logi fir defining TOPDIR, RTDIR and RHDIR
  - redhat: fix a typo in the MRG Makefiles
  - redhat: use bz2 for the tarball instead of xz
  - redhat:  prepared specfile for rhel7-rt-on-rhel6 (with old style module signing)
  - redhat: remove unused config file
  - redhat: add the config files for rhel7-rt-on-rhel6
  - redhat-rt: patch required for rhel7-rt-on-rhel6

* Mon Jul 21 2014 Clark Williams <williams@redhat.com> - 3.10.0-138.rt34.66
- rebased to rhel build 138

* Sun Jul 20 2014 Clark Williams <williams@redhat.com> - 3.10.0-137.rt34.65
- rebased to rhel build 137

* Thu Jul 17 2014 Clark Williams <williams@redhat.com> - 3.10.0-136.rt34.64
- rebased to rhel build 136

* Wed Jul 16 2014 Clark Williams <williams@redhat.com> - 3.10.0-135.rt34.63
- rebased to rhel build 135

* Thu Jul 10 2014 Clark Williams <williams@redhat.com> - 3.10.0-133.rt34.62
- rebased to rhel build 133

* Thu Jul 10 2014 Clark Williams <williams@redhat.com> - 3.10.0-132.rt34.61
- rebased to rhel build 132
- workqueue: Prevent deadlock/stall on RT

* Wed Jul  2 2014 Clark Williams <williams@redhat.com> - 3.10.0-130.rt34.60
- hcd: change local_irq_* functions in URB completion to be nort variants

* Tue Jul  1 2014 Clark Williams <williams@redhat.com> - 3.10.0-130.rt34.59
- rebased to rhel build 130

* Mon Jun 30 2014 Clark Williams <williams@redhat.com> - 3.10.0-128.rt34.58
- nfnetlink_log: unset nf_loggers for net namespace when unload nfnetlink_log

* Wed Jun 25 2014 Clark Williams <williams@redhat.com> - 3.10.0-128.rt34.57
- netconsole: enable netconsole on PREEMPT_RT

* Tue Jun 24 2014 Clark Williams <williams@redhat.com> - 3.10.0-128.rt34.56
- sched: Do not clear PF_NO_SETAFFINITY flag in select_fallback_rq()

* Thu Jun 19 2014 Clark Williams <williams@redhat.com> - 3.10.0-128.rt34.55
- rebased to rhel build 128
- added tglx patch to rtmutex to fix slow path race

* Wed Jun 18 2014 Clark Williams <williams@redhat.com> - 3.10.0-127.rt34.54
- add code to drivers/cpufreq/powernow-k8.c to prevent panic on boot

* Tue Jun 17 2014 Clark Williams <williams@redhat.com> - 3.10.0-127.rt34.53
- turned on CONFIG_NO_HZ_FULL
- turned off CONFIG_NO_HZ_IDLE
- turned on CONFIG_FAIR_GROUP_SCHED
- turned off CONFIG_IRQ_TIME_ACCOUNTING
- turned off CONFIG_

* Mon Jun 16 2014 Clark Williams <williams@redhat.com> - 3.10.0-127.rt34.52
- turned on specfile logic to build virt subpackage

* Thu Jun 12 2014 Clark Williams <williams@redhat.com> - 3.10.0-127.rt34.51
- rebased to rhel build 127

* Fri Jun  6 2014 Clark Williams <williams@redhat.com> - 3.10.0-126.rt34.50
- rebased to rhel build 126
- moved RHEL7 RT infrastructure to redhat/realtime
- added RHEL6 RT infrastructure to redhat/MRG

* Tue Jun  3 2014 Clark Williams <williams@redhat.com> - 3.10.0-124.rt34.49
- rebased to rhel build 124
- futex: Prevent attaching to kernel threads
- futex: Add another early deadlock detection check
- more spefile changes for module signing
- removed sighand debugging patch
- reverted RT commit 'slub: delay ctor until the object is requested'

* Fri May 30 2014 Clark Williams <williams@redhat.com> - 3.10.0-123.rt34.48
- enable module signing

* Thu May 29 2014 Clark Williams <williams@redhat.com> - 3.10.0-123.rt34.47
- debugging patch for sighand from rostedt

* Fri May  9 2014 Clark Williams <williams@redhat.com> - 3.10.0-123.rt34.46
- rt,blk,mq: Make blk_mq_cpu_notify_lock a raw spinlock

* Fri May  9 2014 Clark Williams <williams@redhat.com> - 3.10.0-123.rt34.45
- rt: Move migrate_disable() up in trylocks

* Tue May  6 2014 Clark Williams <williams@redhat.com> - 3.10.0-123.rt34.44
- rebased to rhel build 123

* Mon May  5 2014 Clark Williams <williams@redhat.com> - 3.10.0-122.rt34.43
- rebased to rhel build 122

* Wed Apr  9 2014 Clark Williams <williams@redhat.com> - 3.10.0-121.rt34.42
- rebased to rhel build 121

* Tue Apr  8 2014 Clark Williams <williams@redhat.com> - 3.10.0-120.rt34.41
- rebased to rhel build 120
- synced with upstream 3.10.34-rt34 quilt queue

* Wed Apr  2 2014 Clark Williams <williams@redhat.com> - 3.10.0-118.rt33.40
- rebased to rhel build 118
- modified specfile to use xz compression
- modified config system to turn off CGROUP group schedulers

* Tue Apr  1 2014 Clark Williams <williams@redhat.com> - 3.10.0-117.rt33.39
- rebased to rhel build 117
- from Luis Claudio R. Goncalves <lgoncalv@redhat.com>:
  - spec: do not create an empty include/linux/version.h
  - spec: added ApplyPatch and the support for linux-kernel-test.patch
  - spec: fix the buildid usage on the specfile

* Mon Mar 31 2014 Clark Williams <williams@redhat.com> - 3.10.0-116.rt33.38
- rebased to rhel build 116

* Wed Mar 26 2014 Clark Williams <williams@redhat.com> - 3.10.0-114.rt33.37
- rebased to rhel build 114

* Fri Mar 21 2014 Clark Williams <williams@redhat.com> - 3.10.0-113.rt33.36
- rebased to rhel build 113

* Wed Mar 19 2014 Clark Williams <williams@redhat.com> - 3.10.0-112.rt33.35
- rebased to rhel build 112
- picked up 3.10-rt33 commit:
  - crypto: Reduce preempt disabled regions, more algos
- updated realtime version to -rt33

* Mon Mar 17 2014 Clark Williams <williams@redhat.com> - 3.10.0-111.rt32.34
- rebased to rhel build 111

* Wed Mar 12 2014 Clark Williams <williams@redhat.com> - 3.10.0-109.rt32.33
- rebased to rhel build 109

* Mon Mar 10 2014 Clark Williams <williams@redhat.com> - 3.10.0-107.rt32.32
- pulled new rt-specific patches from latest RT series, updated to -rt32
  - fs: jbd2: pull your plug when waiting for space
  - net: sched: dev_deactivate_many(): use msleep(1) instead of yield()

* Mon Mar 10 2014 Clark Williams <williams@redhat.com> - 3.10.0-107.rt31.31
- rebased to rhel build 107

* Fri Mar  7 2014 Clark Williams <williams@redhat.com> - 3.10.0-106.rt31.30
- rebased to rhel build 106
- reverted removal of stop_cpus_lock in kernel/stop_machine.c

* Wed Mar  5 2014 Clark Williams <williams@redhat.com> - 3.10.0-105.rt31.29
- rebased to rhel build 105

* Tue Mar  4 2014 Clark Williams <williams@redhat.com> - 3.10.0-102.rt31.28
- rebased to rhel build 102

* Tue Mar  4 2014 Clark Williams <williams@redhat.com> - 3.10.0-99.rt31.27
- added rostedt cpu_chill() patch to prevent live-lock

* Mon Mar  3 2014 Clark Williams <williams@redhat.com> - 3.10.0-99.rt31.26
- cherry-picked new RT patches from 3.10.12-rt31 series

* Fri Feb 28 2014 Clark Williams <williams@redhat.com> - 3.10.0-99.rt30.25
- rebased to rhel build 99

* Fri Feb 28 2014 Clark Williams <williams@redhat.com> - 3.10.0-98.rt30.24
- rebased to rhel build 98

* Thu Feb 27 2014 Clark Williams <williams@redhat.com> - 3.10.0-97.rt30.23
- synced with latest 3.10 rt patchset (3.10.32-rt30)

* Wed Feb 26 2014 Clark Williams <williams@redhat.com> - 3.10.0-97.rt25.22
- rebased to rhel build 97

* Wed Feb 26 2014 Clark Williams <williams@redhat.com> - 3.10.0-93.rt25.21
- reworked rebase to use hotplug function from RT patchset

* Mon Feb 24 2014 Clark Williams <williams@redhat.com> - 3.10.0-93.rt25.20
- rebased to rhel build 93
- switched to rhel7 hotplug mechanism in _cpu_down() (kernel/cpu.c)

* Fri Feb 21 2014 Clark Williams <williams@redhat.com> - 3.10.0-90.rt25.19
- rebased to rhel build 90

* Wed Feb 19 2014 Clark Williams <williams@redhat.com> - 3.10.0-89.rt25.18
- added cpu_chill() patch from Sebastian Andrzej Siewior <bigeasy@linutronix.de>

* Tue Feb 18 2014 Clark Williams <williams@redhat.com> - 3.10.0-89.rt25.17
- rebased to rhel build 89
- added 3.12-rt17 series patch to disable cmpxchg for lockref

* Thu Feb 13 2014 Clark Williams <williams@redhat.com> - 3.10.0-87.rt25.16
- rebased to rhel build 87

* Tue Feb 11 2014 Clark Williams <williams@redhat.com> - 3.10.0-86.rt25.15
- rebased to rhel build 86

* Tue Feb 11 2014 Clark Williams <williams@redhat.com> - 3.10.0-85.rt25.14
- rebased to rhel build 85

* Mon Feb 10 2014 Clark Williams <williams@redhat.com> - 3.10.0-84.rt25.13
- rebased to rhel build 84

* Tue Feb  4 2014 Clark Williams <williams@redhat.com> - 3.10.0-82.rt25.12
- fixup mismerge of mm/swap.c

* Tue Feb  4 2014 Clark Williams <williams@redhat.com> - 3.10.0-82.rt25.11
- rebased to rhel build 82

* Wed Jan 22 2014 Clark Williams <williams@redhat.com> - 3.10.0-76.rt25.10
- updated Makefile and kernel-rt.spec to use new versioning scheme

* Wed Jan 15 2014 Clark Williams <williams@redhat.com> - 3.10.0-rt23.9
- change specfile to not build firmware package kernel-rt-firmware

* Tue Jan 14 2014 Clark Williams <williams@redhat.com> - 3.10.0-rt23.8
- rebased to rhel build 68

* Mon Jan 13 2014 Clark Williams <williams@redhat.com> - 3.10.0-rt23.7
- fixed stop_machine issue that prevented system boot

* Wed Jan  8 2014 Clark Williams <williams@redhat.com> - 3.10.0-rt23.6
- remove dependency on rt-firmware package

* Tue Jan  7 2014 Clark Williams <williams@redhat.com> - 3.10.0-rt23.5
- rebased to rhel build 65
- applied sit fix from Willem de Bruijn <willemb@google.com>

* Tue Dec 17 2013 Clark Williams <williams@redhat.com> - 3.10.0-rt19.4
- applied ip6_tunnel fix from Nicolas Dichtel <nicolas.dichtel@6wind.com>

* Tue Dec 17 2013 Clark Williams <williams@redhat.com> - 3.10.0-rt19.3
- rebased to rhel build 62
- added Johannes Berg patch for iwlwifi on RT

* Mon Dec 16 2013 Clark Williams <williams@redhat.com> - 3.10.0-rt19.2
- rebased to 3.10.22-rt19 patchset

* Wed Oct 30 2013 Clark Williams <williams@redhat.com> - 3.10.0-rt18.1
- initial build
